<?php
// generate_color_customize_css
add_action('init', 'ciyashop_version_generate_color_customize_css', 99);

if( !function_exists('ciyashop_version_generate_color_customize_css') ) {
	function ciyashop_version_generate_color_customize_css() {
		global $ciyashop_options;
		
		if( ! class_exists('Redux') ) return;
		
		$header_schema = '';
		$upload = wp_upload_dir();
		$color_customize_file = $upload['basedir'].'/ciyashop/color_customize.css';
		
		if (!file_exists($color_customize_file))
			update_option('theme_version', false);

		$theme_version = get_option('theme_version', false);
		
		if( !version_compare(THEME_VERSION, $theme_version) )
			return;
		
		// Generate the color customizer CSS
		$primary_color   = esc_html( $ciyashop_options['primary_color'] );
		$secondary_color = esc_html( $ciyashop_options['secondary_color'] );
		$tertiary_color  = esc_html( $ciyashop_options['tertiary_color'] );
		
		if( isset( $ciyashop_options['header_type_select'] ) && $ciyashop_options['header_type_select'] != 'predefined' ){
			$header_schema = ciyashop_get_custom_header_schema();
		}

		$color_customize = ciyashop_get_color_scheme_colors( $primary_color, $secondary_color, $tertiary_color, $header_schema );
		ciyashop_generate_color_customize_css( $color_customize );

		update_option('theme_version', THEME_VERSION);
	}
}


/**
 * Add custom image sizes attribute to enhance responsive image functionality
 * for post thumbnails
 */
function ciyashop_post_thumbnail_sizes_attr( $attr, $attachment, $size ) {
	if ( 'post-thumbnails' === $size ) {
		is_active_sidebar( 'sidebar-1' ) && $attr['sizes'] = '(max-width: 709px) 85vw, (max-width: 909px) 67vw, (max-width: 984px) 60vw, (max-width: 1362px) 62vw, 840px';
		! is_active_sidebar( 'sidebar-1' ) && $attr['sizes'] = '(max-width: 709px) 85vw, (max-width: 909px) 67vw, (max-width: 1362px) 88vw, 1200px';
	}
	return $attr;
}
add_filter( 'wp_get_attachment_image_attributes', 'ciyashop_post_thumbnail_sizes_attr', 10 , 3 );

/****************************************************
 *
 * Layout
 *
 ****************************************************/
function ciyashop_site_layout(){
	global $ciyashop_options;

	$site_layout = 'fullwidth';

	if( isset($ciyashop_options['site_layout']) && !empty($ciyashop_options['site_layout']) ){
		$site_layout = $ciyashop_options['site_layout'];
	}

	/**
	 * Filter the layout of the site.
	 *
	 * @since 1.0.0
	 *
	 * @param     string       $site_layout         Site layout.
	 * @param     array        $ciyashop_options    An array of theme options.
	 * 
	 * @visible true
	 */
	$site_layout = apply_filters( 'ciyashop_site_layout', $site_layout, $ciyashop_options );

	return $site_layout;
}

/****************************************************
 *
 * Logo Settings
 *
 ****************************************************/
function ciyashop_logo_type(){
	global $ciyashop_options;

	$logo_type = 'image';
	if( isset($ciyashop_options['logo_type']) && $ciyashop_options['logo_type'] != '' ){
		$logo_type = $ciyashop_options['logo_type'];
	}

	/**
	 * Filter the type of logo.
	 *
	 * @since 1.0.0
	 *
	 * @param     string       $logo_type           Logo Type.
	 * @param     array        $ciyashop_options    An array of theme options.
	 * 
	 * @visible true
	 */
	$logo_type = apply_filters( 'ciyashop_logo_type', $logo_type, $ciyashop_options );

	return $logo_type;
}

function ciyashop_logo_url(){
	global $ciyashop_options;

	$logo_url = get_parent_theme_file_uri('/images/logo.png');

	if( isset($ciyashop_options['site-logo']) && !empty($ciyashop_options['site-logo']['url']) ){
		$logo_url = $ciyashop_options['site-logo']['url'];
	}

	// Replace with Mobile log if on mobile device.
	if ( wp_is_mobile() && ciyashop_mobile_logo_url() ) {
		$logo_url = ciyashop_mobile_logo_url();
	}

	/**
	 * Filter the url of logo.
	 *
	 * @since 1.0.0
	 *
	 * @param     string       $logo_url            Logo URL.
	 * @param     array        $ciyashop_options    An array of theme options.
	 * 
	 * @visible true
	 */
	$logo_url = apply_filters( 'ciyashop_logo_url', $logo_url, $ciyashop_options );

	return $logo_url;
}

function ciyashop_sticky_logo_url(){
	global $ciyashop_options;

	$logo_url = get_parent_theme_file_uri('/images/logo-sticky.png');

	if( isset($ciyashop_options['sticky-logo']) && !empty($ciyashop_options['sticky-logo']['url']) ){
		$logo_url = $ciyashop_options['sticky-logo']['url'];
	}

	/**
	 * Filter the url of sticky logo.
	 *
	 * @since 1.0.0
	 *
	 * @param     string       $logo_url            Sticky logo URL.
	 * @param     array        $ciyashop_options    An array of theme options.
	 * 
	 * @visible true
	 */
	$logo_url = apply_filters( 'ciyashop_sticky_logo_url', $logo_url, $ciyashop_options );

	return $logo_url;
}

function ciyashop_mobile_logo_url(){
	global $ciyashop_options;

	$logo_url = false;

	if( isset($ciyashop_options['mobile-logo']) && !empty($ciyashop_options['mobile-logo']['url']) ){
		$logo_url = $ciyashop_options['mobile-logo']['url'];
	}

	/**
	 * Filter the url of mobile logo.
	 *
	 * @since 1.0.0
	 *
	 * @param     string       $logo_url            Mobile logo URL.
	 * @param     array        $ciyashop_options    An array of theme options.
	 * 
	 * @visible true
	 */
	$logo_url = apply_filters( 'ciyashop_mobile_logo_url', $logo_url, $ciyashop_options );

	return $logo_url;
}

//site Mobile logo settings
if( !function_exists('ciyashop_get_site_mobile_logo') ):
function ciyashop_get_site_mobile_logo(){
	global $ciyashop_options;

	if(isset($ciyashop_options['logo_type']) && $ciyashop_options['logo_type']=='image' && isset($ciyashop_options['mobile-logo']) && isset($ciyashop_options['mobile-logo']['url']) ){
		return $ciyashop_options['mobile-logo']['url'];
	}

	return false;
}
endif;

//site sticky logo settings
if( !function_exists('ciyashop_get_site_sticky_logo') ):
function ciyashop_get_site_sticky_logo(){
	global $ciyashop_options;

	if(isset($ciyashop_options['logo_type']) && $ciyashop_options['logo_type']=='image' &&  isset($ciyashop_options['sticky-logo']) && isset($ciyashop_options['sticky-logo']['url']) ){
		return $ciyashop_options['sticky-logo']['url'];
	}

	return false;
}
endif;

/**
 * site multi lang settings
 */
function ciyashop_get_multi_lang(){
	global $ciyashop_options;

	/*Checl WPML sitepress multilingual plugin activate */
	if( ciyashop_check_plugin_active('sitepress-multilingual-cms/sitepress.php') && function_exists('icl_get_languages') ){
		$ls_settings = get_option('icl_sitepress_settings');
		$languages = icl_get_languages();
        if(!empty($languages)){
			?>
			<div class="language" id="drop">
				<?php
				/* Display Current language */
				foreach($languages as $k => $al ){
					if ( $al[ 'active' ] == 1 ) {
						?>
						<a href="#">
							<?php
							if($al['country_flag_url'] && ( isset($ls_settings['icl_lso_flags']) && $ls_settings['icl_lso_flags']==1 ) ){
								?>
								<img src="<?php echo esc_url($al['country_flag_url']);?>" height="12" alt="<?php echo esc_attr($al['language_code']);?>" width="18" />&nbsp;
								<?php
							}
							echo icl_disp_language($al['native_name'], $al['translated_name']). '&nbsp;<i class="fa fa-angle-down">&nbsp;</i>';
							?>
						</a>
						<?php
						unset( $languages[ $k ] );
						break;
					}
				}
				?>
				<ul class="drop-content">
					<?php
					foreach($languages as $l){
						if(!$l['active']){
							?>
							<li>
								<a href="<?php echo esc_url($l['url']);?>">
									<?php
									if($l['country_flag_url'] && isset($ls_settings['icl_lso_flags']) && $ls_settings['icl_lso_flags']==1){
										?>
										<img src="<?php echo esc_url($l['country_flag_url']);?>" height="12" alt="<?php echo esc_attr($l['language_code']);?>" width="18" />
										<?php
									}
									if(isset($ls_settings['icl_lso_flags']) && $ls_settings['icl_lso_flags']==1){
										echo icl_disp_language($l['native_name'], $l['translated_name']);
									}else{
										echo icl_disp_language($l['native_name']);
									}
									?>
								</a>
							</li>
							<?php
						}
					}
					?>
				</ul>
			</div>
			<?php
		}
	}
}

/**
 * site login options settings
 */
function ciyashop_get_login_options($items, $args){
	/**
	 * Filters active plugins.
	 * 
	 * @param array $active_plugins List of active plugins.
	 * 
	 * @visible false
	 * @ignore
	 */
	if ( function_exists( 'WC' ) ) {
		if (!is_user_logged_in() && $args->theme_location == 'top_menu') {
			$items .= '<li><a href="javascript:void(0);" data-toggle="modal" data-target="#pgs_login_form"><i class="fa fa-sign-in">&nbsp;</i> '.esc_html__('Login', 'ciyashop' ).'</a></li>';
		} elseif (is_user_logged_in() && $args->theme_location == 'top_menu') {
			$items .= '<li><a href="' . esc_url( wp_logout_url( home_url()) ) . '" title="'.esc_attr__('Logout', 'ciyashop' ).'" class="logout"><i class="fa fa-sign-out">&nbsp;</i>  '.esc_html__('Logout', 'ciyashop' ).'</a></li>';
		}
	}
	return $items;
}
add_filter( 'wp_nav_menu_items', 'ciyashop_get_login_options', 10, 2 );

function ciyashop_footer_copyright(){
	global $ciyashop_options;

	$allowed_tags = wp_kses_allowed_html('post');

	$footer_copyright = sprintf( esc_html__( 'Copyright', 'ciyashop' ).' &copy; <span class="copy_year">%1$s</span>, <a href="%2$s" title="%3$s">%4$s</a> '.esc_html__( 'All Rights Reserved.', 'ciyashop' ),
		date('Y'),
		esc_url( home_url( '/' ) ),
		esc_attr( get_bloginfo( 'name', 'display' ) ),
		esc_html( get_bloginfo( 'name', 'display' ) )
	);

	if( isset( $ciyashop_options['footer_copyright'] ) && !empty( $ciyashop_options['footer_copyright'] ) ){
		$footer_copyright = $ciyashop_options['footer_copyright'];
		$footer_copyright = do_shortcode( $footer_copyright );
	}

	/**
	 * Filter the footer copyright content.
	 *
	 * @since 1.0.0
	 *
	 * @param     string       $footer_copyright    Footer copyright content.
	 * @param     array        $ciyashop_options    An array of theme options.
	 * 
	 * @visible true
	 */
	$footer_copyright = apply_filters( 'ciyashop_footer_copyright', $footer_copyright, $ciyashop_options );

	/**
	 * Filter the content before copyright content.
	 *
	 * @since 1.0.0
	 *
	 * @param     string       $before_copyright    Before copyright content. Default null.
	 * @param     array        $ciyashop_options    An array of theme options.
	 * 
	 * @visible true
	 */
	$footer_copyright_before = apply_filters( 'ciyashop_footer_copyright_before', '' );

	/**
	 * Filter the content after copyright content.
	 *
	 * @since 1.0.0
	 *
	 * @param     string       $after_copyright     After copyright content. Default null.
	 * @param     array        $ciyashop_options    An array of theme options.
	 * 
	 * @visible true
	 */
	$footer_copyright_after = apply_filters( 'ciyashop_footer_copyright_after', '' );

	$footer_copyright = $footer_copyright_before . $footer_copyright . $footer_copyright_after;

	echo wp_kses($footer_copyright, array(
		'a'     => $allowed_tags['a'],
		'br'    => $allowed_tags['br'],
		'em'    => $allowed_tags['em'],
		'strong'=> $allowed_tags['strong'],
		'span'  => $allowed_tags['span'],
		'div'   => $allowed_tags['div'],
	));
}

function ciyashop_footer_credits(){
	global $ciyashop_options;

	$ciyashop_credits = sprintf(
		// Translators: %s is the theme credit link.
		esc_html__( 'Developed and designed by %s', 'ciyashop' ),
		'<a href="http://www.potenzaglobalsolutions.com/">' . esc_html__( 'Potenza Global Solutions', 'ciyashop' ) . '</a>'
	);
	
	/**
	 * Filter the footer credit content.
	 *
	 * @since 1.0.0
	 *
	 * @param     string       $ciyashop_credits    Credit content.
	 * @param     array        $ciyashop_options    An array of theme options.
	 * 
	 * @visible true
	 */
	$ciyashop_credits = apply_filters( 'ciyashop_credits', $ciyashop_credits, $ciyashop_options );

	echo wp_kses( $ciyashop_credits, ciyashop_allowed_html( array('i','a','span', 'div', 'ul', 'ol', 'li')) );
}

/**
 * Get product listing page sidebar settings.
 */
function ciyashop_shop_page_sidebar(){
	global $ciyashop_options;

	if( !isset($ciyashop_options) || empty($ciyashop_options) ) return 'left';

	$shop_sidebar = ( isset($ciyashop_options['shop_sidebar']) && !empty($ciyashop_options['shop_sidebar']) ) ? $ciyashop_options['shop_sidebar'] : 'left';

	return $shop_sidebar;
}

function ciyashop_product_page_sidebar(){
	global $ciyashop_options;

	if( !isset($ciyashop_options) || empty($ciyashop_options) ) return 'left';

	$product_sidebar = ( isset($ciyashop_options['product-page-sidebar']) && !empty($ciyashop_options['product-page-sidebar']) ) ? $ciyashop_options['product-page-sidebar'] : 'left';

	return $product_sidebar;
}

function ciyashop_show_sidebar_on_mobile(){
	global $ciyashop_options;

	if( isset($ciyashop_options['show_sidebar_on_mobile']) && $ciyashop_options['show_sidebar_on_mobile'] != '' ){
		return $ciyashop_options['show_sidebar_on_mobile'];
	}

	return 'on';
}

function ciyashop_mobile_sidebar_position(){
	global $ciyashop_options;

	if( isset($ciyashop_options['shop_sidebar_position_mobile']) && !empty($ciyashop_options['shop_sidebar_position_mobile']) ){
		return $ciyashop_options['shop_sidebar_position_mobile'];
	}

	return 'bottom';
}

function ciyashop_device_type(){
	return wp_is_mobile() ? 'mobile' : 'desktop';
}

/**
 * This function use for search woocommerce category based filtering
 */
add_action( 'pre_get_posts','ciyashop_product_cat_search' );
function ciyashop_product_cat_search($query){
	global $wp_the_query;

	if ( $query->is_main_query() && !empty( $wp_the_query->query_vars['wc_query'] ) && isset($_GET['search_category']) && $_GET['search_category'] != '' ){

		$product_tax_query = array(
			array(
				'taxonomy'=> 'product_cat',
				'field'   => 'id',
				'terms'   => sanitize_text_field( wp_unslash( $_GET['search_category'] ) ),
			)
		);
		$query->set( 'tax_query', $product_tax_query );
	}
}

/*
 * Remove pre get pots action for search product category base search
 */
add_action('wp_head','ciyashop_remove_pre_get_posts');
function ciyashop_remove_pre_get_posts(){
	global $wp_the_query;
	if ( !empty( $wp_the_query->query_vars['wc_query'] ) && isset($_GET['search_category']) && $_GET['search_category'] != '' ){
		remove_action( 'pre_get_posts','ciyashop_product_cat_search' );
	}
}

// Change number or products per row to 3
add_filter('loop_shop_columns', 'ciyashop_loop_columns');
if (!function_exists('ciyashop_loop_columns')) {
	function ciyashop_loop_columns() {
		global $ciyashop_options;
		$pro_col_sel = 4;
		if(isset($ciyashop_options['pro-col-sel']) && !empty($ciyashop_options['pro-col-sel'])){
			$pro_col_sel = $ciyashop_options['pro-col-sel'];
		}
		return $pro_col_sel; // 3 products per row
	}
}

/* Change site name to home in breadcrumb */
add_filter('bcn_breadcrumb_title','ciyashop_bcn_breadcrumb_title',10,3);
function ciyashop_bcn_breadcrumb_title($title, $type, $id){
	if($type[0]=='home'){
		$title=esc_html__('Home', 'ciyashop' );
	}
	return $title;
}

function ciyashop_class_builder( $class = '' ){
	$classes = array();

	if ( $class ) {
		if ( ! is_array( $class ) ) {
			$class = preg_split( '#\s+#', $class );
		}
		$classes = array_map( 'esc_attr', $class );
	} else {
		// Ensure that we always coerce class to being an array.
		$class = array();
	}
	$classes = array_map( 'esc_attr', $classes );

	return implode( ' ', array_filter( array_unique( $classes ) ) );
}

function ciyashop_header_type(){

	global $ciyashop_options;
	
	if( isset($ciyashop_options['header_type']) && $ciyashop_options['header_type_select'] == 'header_builder' ){
		$ciyashop_header_type = 'custom';
	}else{
		$ciyashop_header_type = (!empty($ciyashop_options['header_type'])) ? $ciyashop_options['header_type'] : 'menu-center';
	}
	

	/**
	 * Filter header_type.
	 *
	 * @since 1.0.0
	 *
	 * @param     string       $header_type         Header Type.
	 * @param     array        $ciyashop_options    An array of theme options.
	 * 
	 * @visible true
	 */
	$ciyashop_header_type = apply_filters( 'ciyashop_header_type', $ciyashop_header_type, $ciyashop_options );

	return $ciyashop_header_type;
}

function ciyashop_categories_menu_status(){

	global $ciyashop_options;

	if( isset($ciyashop_options['categories_menu_status']) && !empty($ciyashop_options['categories_menu_status']) ){
		$ciyashop_header_type = ciyashop_header_type();
		$categories_menu_status = in_array( $ciyashop_header_type, array('default', 'logo-center', 'topbar-with-main-header') ) ? $ciyashop_options['categories_menu_status'] : 'disable';
	}else{
		$categories_menu_status = 'disable';
	}

	/**
	 * Filters the status of the categories menu.
	 *
	 * @since 1.0.0
	 *
	 * @param     string       $menu_status         Categories menu status.
	 * @param     array        $ciyashop_options    An array of theme options.
	 * 
	 * @visible true
	 */
	$categories_menu_status = apply_filters( 'ciyashop_categories_menu_status', $categories_menu_status, $ciyashop_options );

	return $categories_menu_status;
}

function ciyashop_topbar_enable(){

	global $ciyashop_options;

	$topbar_enable_stat = ( isset($ciyashop_options['topbar_enable']) && $ciyashop_options['topbar_enable'] != '' ) ? $ciyashop_options['topbar_enable'] : true;

	if( $topbar_enable_stat ){
		$topbar_enable = 'enable';
	}else{
		$topbar_enable = 'disable';
	}

	/**
	 * Filters whether to enable topbar.
	 *
	 * @since 1.0.0
	 *
	 * @param     boolean      $topbar_enable       Whether to enable the topbar.
	 * @param     array        $ciyashop_options    An array of theme options.
	 * 
	 * @visible true
	 */
	$topbar_enable = apply_filters( 'ciyashop_topbar_enable', $topbar_enable, $ciyashop_options );

	return $topbar_enable;
}

function ciyashop_topbar_mobile_enable(){

	global $ciyashop_options;

	$topbar_mobile_enable_stat = ( isset($ciyashop_options['topbar_mobile_enable']) && $ciyashop_options['topbar_mobile_enable'] != '' ) ? $ciyashop_options['topbar_mobile_enable'] : true;

	if( $topbar_mobile_enable_stat && ciyashop_topbar_enable() == 'enable' ){
		$topbar_mobile_enable = 'enable';
	}else{
		$topbar_mobile_enable = 'disable';
	}

	/**
	 * Filters whether to enable topbar in mobile.
	 *
	 * @since 1.0.0
	 *
	 * @param     string      $enable_topbar        Whether to enable topbar in mobile.
	 * @param     array       $ciyashop_options     An array of theme options.
	 * 
	 * @visible true
	 */
	$topbar_mobile_enable = apply_filters( 'ciyashop_topbar_mobile_enable', $topbar_mobile_enable, $ciyashop_options );

	return $topbar_mobile_enable;
}

function ciyashop_social_profiles(){
	global $ciyashop_options;
	
	/**
	 * Filters the list of social profiles.
	 *
	 * @param    array    $social_profiles        An array of social profiles.
	 * 
	 * @visible true
	 */
	$social_profiles = apply_filters('ciyashop_social_profiles',array(
		'facebook' => array(
			'key'      => 'facebook',
			'name'     => esc_html__('Facebook', 'ciyashop' ),
			'icon'     => '<i class="fa fa-facebook"></i>',
		),
		'twitter'  => array(
			'key'          => 'twitter',
			'name'         => esc_html__('Twitter', 'ciyashop' ),
			'icon'         => '<i class="fa fa-twitter"></i>',
		),
		'googleplus'  => array(
			'key'          => 'googleplus',
			'name'         => esc_html__('Google+', 'ciyashop' ),
			'icon'         => '<i class="fa fa-google-plus"></i>',
		),
		'dribbble'  => array(
			'key'          => 'Dribbble',
			'name'         => esc_html__('Dribbble', 'ciyashop' ),
			'icon'         => '<i class="fa fa-dribbble"></i>',
		),
		'vimeo'    => array(
			'key'          => 'vimeo',
			'name'         => esc_html__('Vimeo', 'ciyashop' ),
			'icon'         => '<i class="fa fa-vimeo"></i>',
		),
		'pinterest'=> array(
			'key'          => 'pinterest',
			'name'         => esc_html__('Pinterest', 'ciyashop' ),
			'icon'         => '<i class="fa fa-pinterest"></i>',
		),
		'behance'  => array(
			'key'          => 'behance',
			'name'         => esc_html__('Behance', 'ciyashop' ),
			'icon'         => '<i class="fa fa-behance"></i>',
		),
		'linkedin' => array(
			'key'          => 'linkedin',
			'name'         => esc_html__('Linkedin', 'ciyashop' ),
			'icon'         => '<i class="fa fa-linkedin"></i>',
		),
		'youtube' => array(
			'key'          => 'youtube',
			'name'         => esc_html__('YouTube', 'ciyashop' ),
			'icon'         => '<i class="fa fa-youtube-play"></i>',
		),
		'instagram' =>array(
			'key'          => 'instagram',
			'name'         => esc_html__('instagram', 'ciyashop' ),
			'icon'         => '<i class="fa fa-instagram"></i>',
		),
	));

	if( !isset($ciyashop_options['social_media_icons']) || $ciyashop_options['social_media_icons'] == '' ){
		return '';
	}
	$total_social_icon = count( $ciyashop_options['social_media_icons']['redux_repeater_data'] );

	$social_profiles_data = array();
	for( $i=0; $i<$total_social_icon; $i++ ){
		if($ciyashop_options['social_media_icons']['social_media_type'][$i]=='custom'){
			$social_icon_href = $ciyashop_options['social_media_icons']['social_media_url'][$i];
			$social_icon      = $ciyashop_options['social_media_icons']['custom_soical_icon'][$i];
			$social_title     = $ciyashop_options['social_media_icons']['custom_social_title'][$i];

			if( !empty($social_icon_href) && !empty($social_icon) ){
				$social_profiles_data[] = array(
					'link'  => esc_url($social_icon_href),
					'icon'  => '<i class="'.esc_attr('fa '.$social_icon).'"></i>',
					'title' => esc_attr($social_title),
				);
			}
		}else{
			$social_icon_href = isset( $ciyashop_options['social_media_icons']['social_media_url'][$i] ) ? $ciyashop_options['social_media_icons']['social_media_url'][$i] : '';
			$social_icon      = $ciyashop_options['social_media_icons']['social_media_type'][$i];
			$social_title     = ucfirst($ciyashop_options['social_media_icons']['social_media_type'][$i]);

			if( !empty($social_icon_href) && isset($social_profiles[$social_icon]['icon']) ){
				$social_profiles_data[] = array(
					'link'  => esc_url($social_icon_href),
					'icon'  => $social_profiles[$social_icon]['icon'],
					'title' => esc_attr($social_title),
				);
			}
		}
	}
	return $social_profiles_data;
}


function ciyashop_opening_hours(){
	global $ciyashop_options;

	$ciyashop_opening_hours_data =  array(

		esc_html__( 'Monday', 'ciyashop' )    => isset( $ciyashop_options['mon_time']) ? $ciyashop_options['mon_time'] : '',
		esc_html__( 'Tuesday', 'ciyashop' )   => isset( $ciyashop_options['tue_time']) ? $ciyashop_options['tue_time'] : '',
		esc_html__( 'Wednesday', 'ciyashop' ) => isset( $ciyashop_options['wed_time']) ? $ciyashop_options['wed_time'] : '',
		esc_html__( 'Thursday', 'ciyashop' )  => isset( $ciyashop_options['thu_time']) ? $ciyashop_options['thu_time'] : '',
		esc_html__( 'Friday', 'ciyashop' )    => isset( $ciyashop_options['fri_time']) ? $ciyashop_options['fri_time'] : '',
		esc_html__( 'Saturday', 'ciyashop' )  => isset( $ciyashop_options['sat_time']) ? $ciyashop_options['sat_time'] : '',
		esc_html__( 'Sunday', 'ciyashop' )    => isset( $ciyashop_options['sun_time']) ? $ciyashop_options['sun_time'] : '',

	);
	return $ciyashop_opening_hours_data;
}

/*
 * Return whether Visual Composer is enabled on a page/post or not.
 *
 * $post_id = numeric post_id
 * return true/false
 */
function ciyashop_is_vc_enabled( $post_id = '' ){
	global $post;

	if( is_search() || is_404() || empty($post)  ) return;

	if( empty( $post_id ) ){
		$post_id = $post->ID;
	}
	$vc_enabled = get_post_meta( $post_id, '_wpb_vc_js_status', true );
	return ($vc_enabled=='true')? true : false;
}

/**
 * Converts a multidimensional array of CSS rules into a CSS string.
 *
 * @param array $rules
 *   An array of CSS rules in the form of:
 *   array('selector'=>array('property' => 'value')). Also supports selector
 *   nesting, e.g.,
 *   array('selector' => array('selector'=>array('property' => 'value'))).
 *
 * @return string
 *   A CSS string of rules. This is not wrapped in style tags.
 *
 * source : http://www.grasmash.com/article/convert-nested-php-array-css-string
 */
function ciyashop_generate_css_properties($rules, $indent = 0) {
	$css = '';
	$prefix = str_repeat('  ', $indent);
	foreach ($rules as $key => $value) {
		if (is_array($value)) {
			$selector = $key;
			$properties = $value;

			$css .= $prefix . "$selector {\n";
			$css .= $prefix .ciyashop_generate_css_properties($properties, $indent + 1);
			$css .= $prefix . "}\n";
		}
		else {
			$property = $key;
			$css .= $prefix . "$property: $value;\n";
		}
	}
	return $css;
}

function ciyashop_get_file_list( $extensions = '', $path = '' ){

	// Return if any paramater is blank
	if( empty($extensions) || empty($path) ){
		return false;
	}

	// Convert to array if string is provided
	if( !is_array($extensions) ){
		$extensions = array_filter( explode(',', $extensions) );
	}

	// Fix trailing slash if not provided.
	$path = rtrim( $path, '/\\' ) . '/';

	if ( defined( 'GLOB_BRACE' ) ){
		if( count($extensions) == 1 && $extensions[0] == '*' ){
			$files_with_glob = glob( $path."*", GLOB_BRACE );
		}else{
			$extensions_with_glob_brace = "{". implode(',', $extensions)."}"; // file extensions pattern
			$files_with_glob = glob( $path."*.$extensions_with_glob_brace", GLOB_BRACE );
		}

		return $files_with_glob;
	}else{
		if( count($extensions) == 1 && $extensions[0] == '*' ){
			$files_without_glob = glob( $path."*" );
		}else{
			$extensions_without_glob = implode('|', $extensions); // file extensions pattern


			$files_without_glob_all = glob( $path.'*.*' ); // Get all files


			$files_without_glob = array_values( preg_grep("~\.($extensions_without_glob)$~", $files_without_glob_all) ); // Filter files with pattern
		}
		return $files_without_glob;
	}

	return $files;
}

add_action('wp_footer','ciyashop_promo_popup');
function ciyashop_promo_popup(){
	global $ciyashop_options;
	$content_css   = '';

	if(isset($ciyashop_options['promo_popup']) && $ciyashop_options['promo_popup']){

		$content_style = array();

		// Background
		if( isset($ciyashop_options['popup-background']['background-color']) && !empty($ciyashop_options['popup-background']['background-color']) && $ciyashop_options['popup-background']['background-color'] != 'transparent' ){
			$content_style['background-color'] = 'background-color:'.$ciyashop_options['popup-background']['background-color'];
		}
		if( isset($ciyashop_options['popup-background']['background-repeat']) && !empty($ciyashop_options['popup-background']['background-repeat']) ){
			$content_style['background-repeat'] = 'background-repeat:'.$ciyashop_options['popup-background']['background-repeat'];
		}
		if( isset($ciyashop_options['popup-background']['background-size']) && !empty($ciyashop_options['popup-background']['background-size']) ){
			$content_style['background-size'] = 'background-size:'.$ciyashop_options['popup-background']['background-size'];
		}
		if( isset($ciyashop_options['popup-background']['background-attachment']) && !empty($ciyashop_options['popup-background']['background-attachment']) ){
			$content_style['background-attachment'] = 'background-attachment:'.$ciyashop_options['popup-background']['background-attachment'];
		}
		if( isset($ciyashop_options['popup-background']['background-position']) && !empty($ciyashop_options['popup-background']['background-position']) ){
			$content_style['background-position'] = 'background-position:'.$ciyashop_options['popup-background']['background-position'];
		}
		if( isset($ciyashop_options['popup-background']['background-image']) && !empty($ciyashop_options['popup-background']['background-image']) ){
			$content_style['background-image'] = 'background-image:url('.$ciyashop_options['popup-background']['background-image'].')';
		}

		if( $content_style && is_array($content_style) && !empty($content_style) ){
			$content_css = implode( ';', array_filter( array_unique( $content_style ) ) );
		}

		?>
		<div class="ciyashop-promo-popup mfp-hide">
			<div class="ciyashop-popup-inner" style="<?php echo esc_attr($content_css);?>">
				<?php echo do_shortcode( $ciyashop_options['popup_text']); ?>
			</div>
		</div>
		<?php
	}
}

// Convert hexdec color string to rgb(a) string
// Source : https://support.advancedcustomfields.com/forums/topic/color-picker-values/
function ciyashop_hex2rgba($color = '', $opacity = false) {

	$default = 'rgb(0,0,0)';

	//Return default if no color provided
	if(empty($color)) return $default;

	//Sanitize $color if "#" is provided
	if ($color[0] == '#' ) {
		$color = substr( $color, 1 );
	}

	//Check if color has 6 or 3 characters and get values
	if (strlen($color) == 6) {
		$hex = array( $color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5] );
	} elseif ( strlen( $color ) == 3 ) {
		$hex = array( $color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2] );
	} else {
		return $default;
	}

	//Convert hexadec to rgb
	$rgb =  array_map('hexdec', $hex);

	//Check if opacity is set(rgba or rgb)
	if($opacity){
		if(abs($opacity) > 1)
			$opacity = 1.0;
		$output = 'rgba('.implode(",", $rgb).','.$opacity.')';
	} else {
		$output = 'rgb('.implode(",", $rgb).')';
	}

	//Return rgb(a) color string
	return $output;
}

function ciyashop_hex2rgb( $color ) {
	if ( $color[0] == '#' ) {
		$color = substr( $color, 1 );
	}
	if (strlen($color) == 6) {
		list( $r, $g, $b ) = array( $color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5] );
	} elseif (strlen($color) == 3) {
		list( $r, $g, $b ) = array( $color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2] );
	} else {
		return false;
	}

	$r = hexdec( $r );
	$g = hexdec( $g );
	$b = hexdec( $b );

	return array( 'r' => $r, 'g' => $g, 'b' => $b );
}

function ciyashop_sticky_header(){
	global $ciyashop_options;

	$sticky_header = isset($ciyashop_options['sticky_header']) ? $ciyashop_options['sticky_header'] : true;

	/**
	 * Filters whether to enable sticky header.
	 *
	 * @since 1.0.0
	 *
	 * @param     boolean       $enable_sticky      Whether to enable the sticky header.
	 * @param     array         $ciyashop_options   An array of theme options.
	 * 
	 * @visible true
	 */
	$sticky_header = apply_filters( 'ciyashop_sticky_header', $sticky_header, $ciyashop_options );

	return $sticky_header;
}

function ciyashop_mobile_sticky_header(){
	global $ciyashop_options;

	$ciyashop_sticky_header = ciyashop_sticky_header();

	if( !$ciyashop_sticky_header ) return false;

	$mobile_sticky_header = isset($ciyashop_options['mobile_sticky_header']) ? $ciyashop_options['mobile_sticky_header'] : true;

	/**
	 * Filters whether to enable sticky header in mobile.
	 *
	 * @since 1.0.0
	 *
	 * @param     boolean       $enable_sticky      Whether to enable the sticky header in mobile.
	 * @param     array         $ciyashop_options   An array of theme options.
	 * 
	 * @visible true
	 */
	$mobile_sticky_header = apply_filters( 'ciyashop_mobile_sticky_header', $mobile_sticky_header, $ciyashop_options );

	return $mobile_sticky_header;
}

/*
 * Display Related Post in single blog post
 */
function ciyashop_related_posts(){
	global $ciyashop_options;

	$related_posts = ( isset($ciyashop_options['related_posts']) ) ? $ciyashop_options['related_posts'] : false;

	if( $related_posts == 0 ){
		return;
	}

	$category_terms = wp_get_post_terms( get_the_ID(), 'category');
	$cat_id=array();
	if(!empty($category_terms)){
		foreach($category_terms as $value){
			$cat_id[]=$value->term_id;
		}
	}
	$args = array(
		'post_type'     => 'post',
		'posts_per_page'=> 10,
		'post__not_in'  => array(get_the_ID()),
		'tax_query'     => array(
			array(
				'taxonomy' => 'category',
				'field'    => 'id',
				'terms'    => $cat_id,
			),
		),
	);
	$related_post_query = new WP_Query( $args );

	$owl_options_args = array(
		'items'             => 3,
		'loop'              => false,
		'dots'              => false,
		'nav'               => true,
		'margin'            => 10,
		'autoplay'          => true,
		'autoplayHoverPause'=> true,
		'smartSpeed'        => 1000,
		'responsive'        => array(
			0    => array(
				'items'=> 1,
			),
			480  => array(
				'items'=> 1,
			),
			577 => array(
				'items' => 2,
			),
			980 => array(
				'items' => 3,
			),
			1200 => array(
				'items' => 3,
			),
		),
		'navText' => array(
			"<i class='fa fa-angle-left fa-2x'>&nbsp;</i>",
			"<i class='fa fa-angle-right fa-2x'>&nbsp;</i>",
		),
		'lazyLoad' => (isset($ciyashop_options['enable_lazyload']) && $ciyashop_options['enable_lazyload']) ? true : false,
	);

	$owl_options = '';
	if( is_array($owl_options_args) && !empty($owl_options_args) ){
		$owl_options = json_encode($owl_options_args);
	}
	?>
	<div class="related-posts">
		<h3 class="title"><?php esc_html_e('Related Posts','ciyashop' );?></h3>
		<div class="related-posts-section">
			<div class="owl-carousel owl-theme owl-carousel-options" data-owl_options="<?php echo esc_attr($owl_options);?>">
			<?php
			if($related_post_query->have_posts()){
				while($related_post_query->have_posts()){ $related_post_query->the_post(); ?>
					<div class="item">
						<div class="related-post-info">
							<div class="post-image clearfix<?php echo ( !has_post_thumbnail() ) ? ' no-post-image' : '';?>">
								<?php
								if ( has_post_thumbnail() ) {
									if(isset($ciyashop_options['enable_lazyload']) && $ciyashop_options['enable_lazyload']) {
										echo '<img class="owl-lazy img-fluid" src="'. esc_url(LOADER_IMAGE) .'" data-src="'. esc_url(get_the_post_thumbnail_url( '', 'ciyashop-latest-post-thumbnail' )) .'" alt="'. esc_attr(get_the_title()) .'" />';
									} else {
										echo '<img class="img-fluid" src="'. esc_url(get_the_post_thumbnail_url( '', 'ciyashop-latest-post-thumbnail' )) .'" alt="'. esc_attr(get_the_title()) .'" />';
									}
								}
								?>
							</div>
							<span class="post-<?php echo ( !has_post_thumbnail() ) ? 'no-image-text' : 'image-text';?>">
								<?php the_title( '<h5 class="title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h5>' ); ?>
							</span>
						</div>
					</div>
				<?php }
			}
			wp_reset_postdata();
			?>
			</div>
		</div>
	</div>
	<?php
}

/*
 * Display Author box in single blog post
 */
function ciyashop_authorbox(){
	global $ciyashop_options;

	$author_details = ( isset($ciyashop_options['author_details']) ) ? $ciyashop_options['author_details'] : true;

	if( $author_details == 0 )
		return;

	if ( is_singular() && get_the_author_meta( 'description' ) ) : // If a user has filled out their description and this is a multi-author blog, show a bio on their entries. ?>
		<div class="author-info">
			<div class="author-avatar media-left">
				<?php
				/**
				 * Filters avatar size of author.
				 *
				 * @since 1.0.0
				 *
				 * @param     int       $avatar_size      Avatar size. Default 68.
				 * 
				 * @visible true
				 */
				$author_bio_avatar_size = apply_filters( 'ciyashop_author_bio_avatar_size', 68 );
				echo get_avatar( get_the_author_meta( 'user_email' ), $author_bio_avatar_size );
				?>
			</div><!-- .author-avatar -->
			<div class="author-description media-body">
				<h5 class="title author-title"><?php printf( esc_html__( 'About %s', 'ciyashop' ), get_the_author() ); ?></h5>
				<p><?php the_author_meta( 'description' ); ?></p>
			</div><!-- .author-description -->
		</div><!-- .author-info -->
		<?php
	endif;
}

function ciyashop_get_excerpt_max_charlength($charlength, $excerpt = null) {
	if( empty($excerpt) ){
		$excerpt = get_the_excerpt();
	}
	$charlength++;

	if ( mb_strlen( $excerpt ) > $charlength ) {
		$subex = mb_substr( $excerpt, 0, $charlength - 5 );
		$exwords = explode( ' ', $subex );
		$excut = - ( mb_strlen( $exwords[ count( $exwords ) - 1 ] ) );

		$new_excerpt = '';
		if ( $excut < 0 ) {
			$new_excerpt = mb_substr( $subex, 0, $excut );
		} else {
			$new_excerpt = $subex;
		}
		$new_excerpt .= '[...]';
		return $new_excerpt;
	}

	return $excerpt;
}
function ciyashop_the_excerpt_max_charlength($charlength, $excerpt = null) {
	echo ciyashop_get_excerpt_max_charlength($charlength, $excerpt);
}

function ciyashop_validate_css_unit( $str = '', $units = array() ){

	// bail early if any param is empty
	if( !is_string($str) || $str == '' || !is_array($units) || empty($units) ) return false;

	// prepare units string
	$units_str = implode('|',$units);

	// prepare regex
	$reg_ex = '/^(auto|0)$|^[+-]?[0-9]+.?([0-9]+)?('.$units_str.')$/';

	// check match
	preg_match_all($reg_ex, $str, $matches, PREG_SET_ORDER, 0);

	// check if matched found.
	if( count($matches) > 0 ) return true;

	return false;
}

/*
 * Update Theme option favicon icon from customizer site icon
 */
add_action('customize_save_response', 'ciyashop_customize_save_response', 10, 2);
function ciyashop_customize_save_response($response, $data){
	global $ciyashop_globals;

	if( isset($_POST['customized']) ){
		$post_values = json_decode( sanitize_text_field( wp_unslash( $_POST['customized'] ) ), true );

		if( isset($post_values['site_icon']) && $post_values['site_icon'] != '' ){
			$opt_name         = $ciyashop_globals['theme_option'];
			$ciyashop_options= get_option( $opt_name );
			$site_icon        = $post_values['site_icon'];
			$img              = wp_get_attachment_image_src( $site_icon, 'full' );
			$thumbnail        = wp_get_attachment_image_src( $site_icon, 'thumbnail' );

			$ciyashop_options['favicon_icon']['url']      = $img[0];
			$ciyashop_options['favicon_icon']['id']       = $site_icon;
			$ciyashop_options['favicon_icon']['width']    = $img[1];
			$ciyashop_options['favicon_icon']['height']   = $img[2];
			$ciyashop_options['favicon_icon']['thumbnail']= $thumbnail[0];
			update_option( $opt_name, $ciyashop_options );
		}
	}

	return $response;
}

/*
 * Update customizer site icon from theme option favicon icon
 */
add_filter( "redux/options/ciyashop_options/ajax_save/response", 'ciyashop_option_save' );
function ciyashop_option_save( $response ){
	if( isset($response['options']['favicon_icon']) && !empty($response['options']['favicon_icon']) ){
		$site_icon = get_option( 'site_icon' );
		$favicon_icon = $response['options']['favicon_icon']['id'];
		if( $favicon_icon != $site_icon){
			update_option( 'site_icon', $favicon_icon);
		}
	}

	return $response;
}

function ciyashop_get_product_categories(){
	$cat_titles = array();

	if( is_admin() ){
		$args = array(
			'type'        => 'post',
			'orderby'     => 'id',
			'order'       => 'DESC',
			'hide_empty'  => false,
			'hierarchical'=> 1,
			'taxonomy'    => 'product_cat',
			'pad_counts'  => false,
		);

		$post_categories = get_categories($args);


		foreach( $post_categories as $cat ) {
			$cat_titles[$cat->term_id] = $cat->name;
		}
	}
	return $cat_titles;
}

if ( ! function_exists( 'ciyashop_array_unshift_assoc' ) ) {
	function ciyashop_array_unshift_assoc( &$arr, $key, $val ) {
		$arr        = array_reverse( $arr, true );
		$arr[ $key ]= $val;
		$arr        = array_reverse( $arr, true );
	}
}

function ciyashop_allowed_html( $allowed_els = '' ){

	// bail early if parameter is empty
	if( empty($allowed_els) ) return array();

	if( is_string($allowed_els) ){
		$allowed_els = explode(',', $allowed_els);
	}

	$allowed_html = array();

	$allowed_tags = wp_kses_allowed_html('post');

	foreach( $allowed_els as $el ){
		$el = trim($el);
		if( array_key_exists($el, $allowed_tags) ){
			$allowed_html[$el] = $allowed_tags[$el];
		}
	}

	return $allowed_html;
}

//ciyashop_auto_complate_search
add_action('wp_ajax_ciyashop_auto_complete_search','ciyashop_auto_complete_search');
add_action('wp_ajax_nopriv_ciyashop_auto_complete_search','ciyashop_auto_complete_search');

function ciyashop_auto_complete_search(){
	global $ciyashop_options, $post;

	$search_keyword   = isset( $_POST['search_keyword'] ) ? sanitize_text_field( wp_unslash( $_POST['search_keyword'] ) ) : '';
	$search_category  = isset( $_POST['search_category'] ) ? sanitize_text_field( wp_unslash( $_POST['search_category'] ) ) : '';

	$post_titles = array();

	$taxonomy = ($ciyashop_options['search_content_type']=='product') ? 'product_cat' : 'category';
	$post_type = (!empty($ciyashop_options['search_content_type'])) ? $ciyashop_options['search_content_type'] : 'post';

	if($post_type == 'all'){
		$post_type = 'any';
	}

	$args = array(
		'post_type' => $post_type,
		'post_status' => 'publish',
		'posts_per_page' => -1,
	);

	if( !empty($search_keyword) ){
		$args['s'] = $search_keyword;
	}

	if(!empty($search_category)){
		$args['tax_query'][] = array(
			'taxonomy' => $taxonomy,
			'field'    => 'id',
			'terms'    => $search_category,
		 );
	}

	/**
	 * Filters the autocomplete search arguments.
	 *
	 * @since 3.4.4
	 *
	 * @param     array       $args         An array of search arguments.
	 *
	 * @visible true
	 */
	$args = apply_filters( 'ciyashop_auto_complete_search_args', $args );

	$posts = new WP_Query( $args );

	while ( $posts->have_posts() ) : $posts->the_post();
		$img = get_the_post_thumbnail($posts->ID,'ciyashop-thumbnail-small');
		$data[] = array(
			'post_title' => $post->post_title,
			'post_img' => $img,
			'post_link' => get_the_permalink( $post->ID )
		);
    endwhile;
	wp_reset_query();

	/**
	 * Filters the autocomplete search result.
	 *
	 * @since 3.4.4
	 *
	 * @param     array       $args         An array of search data.
	 * @param     array       $args         An array of search arguments.
	 * 
	 * @visible true
	 */
	$data = apply_filters( 'ciyashop_auto_complete_search_data', $data, $args );

	echo json_encode($data);
    exit();
}

add_filter( 'woocommerce_widget_cart_is_hidden', 'ciyashop_widget_cart_is_hidden' ) ;
function ciyashop_widget_cart_is_hidden(){
	return false;
}

function ciyashop_check_plugin_active( $plugin = '' ) {

	if( empty($plugin) ) return false;

	return ( in_array( $plugin, (array) get_option( 'active_plugins', array() ) ) || ( function_exists('is_plugin_active_for_network') && is_plugin_active_for_network($plugin) ) );
}

add_action('ciyashop_before_footer', 'ciyashop_sticky_footer_mobile_device');
function ciyashop_sticky_footer_mobile_device() {
	global $ciyashop_options;

	if ( ( isset($ciyashop_options['woocommerce_mobile_sticky_footer']) && $ciyashop_options['woocommerce_mobile_sticky_footer'] ) && ( function_exists('is_product') && !is_product() ) && wp_is_mobile() ) {
		get_template_part( 'template-parts/footer/sticky-footer-mobile' );
	}
}

function ciyashop_is_activated() {
	$purchase_token = get_option('ciyashop_pgs_token');
	if( $purchase_token && !empty($purchase_token)){
		return $purchase_token;
	}
	return false;
}

// Display admin notice if PGS Core is not updated.
function ciyashop_pgscore_update_notice() {

	$current_theme = wp_get_theme();

	if( !defined('PGSCORE_PATH') ) return;

	if(
		( !defined('PGSCORE_VERSION') || ( defined('PGSCORE_VERSION') && version_compare( PGSCORE_VERSION,'4.3.0', '<' ) ) )
	){
		$ciyashop_token = ciyashop_is_activated();
		if( $ciyashop_token ){
			$title     = esc_html__( 'Update PGS Core', 'ciyashop' );
			$msg       = '<p>'. __( 'Please ensure to update PGS Core plugin to latest version to enable features.', 'ciyashop' );
			$btn_title = esc_html__( 'Update PGS Core', 'ciyashop' );
			$url       = add_query_arg( array(
				'page' => 'theme-plugins',
				'plugin_status' => 'update',
			), admin_url('themes.php') );

		}else{
			$title     = esc_html__( 'Activate Theme', 'ciyashop' );
			$msg       = esc_html__( 'Please activate theme to enable the theme features.', 'ciyashop' );
			$btn_title = esc_html__( 'Activate Theme', 'ciyashop' );
			$url       = add_query_arg( array(
				'page' => 'ciyashop-panel',
			), admin_url('admin.php') );

		}
		?>
		<div id="setting-error-pgscore_update" class="notice notice-error">
			<h2 class="setting-error-pgscore_update-header"><i class="dashicons dashicons-warning"></i> <?php echo esc_html($title);?></h2>
			<div class="setting-error-pgscore_update-desc"><?php echo wp_kses($msg, array('p'=> array()));?></div>
			<div class="setting-error-pgscore_update-action"><a href="<?php echo esc_url($url); ?>" class="button-primary"><?php echo esc_html($btn_title);?></a></div>
		</div>
		<?php
	}
}
add_action( 'admin_notices', 'ciyashop_pgscore_update_notice' );

/**
 * ------------------------------------------------------------------------------------------------
 * Function returns numbers of items in the wishlist
 * ------------------------------------------------------------------------------------------------
 */
if( ! function_exists( 'ciyashop_get_wishlist_number' ) ) {
	function ciyashop_get_wishlist_number() {
		if( ! class_exists( 'YITH_WCWL' ) ) die();
		echo YITH_WCWL()->count_products();
		die();
	}
	add_action( 'wp_ajax_ciyashop_get_wishlist_number', 'ciyashop_get_wishlist_number' );
	add_action( 'wp_ajax_nopriv_ciyashop_get_wishlist_number', 'ciyashop_get_wishlist_number' );
}

// Portfolio container class
add_filter('ciyashop_content_container_classes','ciyashop_main_content_container_classes');
function ciyashop_main_content_container_classes( $classes ){
	global $ciyashop_options;

	if( is_post_type_archive('portfolio') && $ciyashop_options['portfolio_sidebar']=='full_width' && $ciyashop_options['portfolio_fullscreen'] == 1){
		$classes = array('container-fluid');
	}
	return $classes;
}

/****************************************************
 *
 * Related Portfolio
 *
 ****************************************************/

function ciyashop_related_portfolio(){
	global $ciyashop_options;

	if( isset($ciyashop_options['display_related_portfolio']) && $ciyashop_options['display_related_portfolio'] == 1 ){
		get_template_part( 'template-parts/portfolio/single-related' );
	}
}

/****************************************************
 *
 * Custome Sidebar
 *
 ****************************************************/

// Register Metabox
function ciyashop_custome_sidebar_metabox() {
	add_meta_box(
		'pgs_custome_sidebar',
		__( 'Custome Sidebar', 'ciyashop' ),
		'pgs_custome_sidebar_callback',
		'page',
		'side'
	);
}

add_action( 'add_meta_boxes', 'ciyashop_custome_sidebar_metabox' ); // phpcs:ignore WordPress.XSS.EscapeOutput.OutputNotEscaped

// Metabox Dropdown
function pgs_custome_sidebar_callback( $post ){
	wp_nonce_field( 'pgs_custom_sidebar_metabox_nonce', 'pgs_custom_sidebar_nonce' );
	$value   = get_post_meta( $post->ID, 'pgs_custom_sidebar', true );
	?>
	<select name="pgs_custom_sidebar" id="pgs_custom_sidebar">
		<option value="">
			<?php echo esc_html('Default'); ?>
		</option>
		<?php foreach ( $GLOBALS['wp_registered_sidebars'] as $sidebar ) {?>
		<option value="<?php echo esc_attr( $sidebar['id'] ); ?>" <?php selected( $value, $sidebar['id'] );?>>
			<?php echo esc_html( ucwords( $sidebar['name'] ) ); ?>
		</option>
		<?php
	}?>
	</select>
	<?php
}

// Metabox Save
if( ! function_exists( 'ciyashop_save_custome_sidebar_metabox' ) ) {
	function ciyashop_save_custome_sidebar_metabox( $post_id ) {
		if( !isset( $_POST['pgs_custom_sidebar_nonce'] ) || !wp_verify_nonce( $_POST['pgs_custom_sidebar_nonce'], 'pgs_custom_sidebar_metabox_nonce') )
			return;

		if ( !current_user_can( 'edit_post', $post_id ))
			return;

		if ( isset($_POST['pgs_custom_sidebar']) ) {
			update_post_meta($post_id, 'pgs_custom_sidebar', sanitize_text_field($_POST['pgs_custom_sidebar']));
		}
	}
}
add_action('save_post', 'ciyashop_save_custome_sidebar_metabox');

// Redux Search Option
if( ! function_exists( 'redux_search_options' ) ) {
	function redux_search_options(){

		global $ciyashop_globals, $ciyashop_options, $pgscore_globals;

		if( class_exists('Redux') ) {

			$option_fields = array();

			// Sections
			$ciyashop_redux_sections = Redux::$sections;

			if( empty($ciyashop_redux_sections ) ) return;

			$ciyashop_redux_sections = $ciyashop_redux_sections[$ciyashop_globals['options_name']];
			$sections_count = ( Redux_Helpers::isWpDebug() ) ? count($ciyashop_redux_sections) + 2 : count($ciyashop_redux_sections) + 1;

			// Fields
			$ciyashop_redux_fields = Redux::$fields;
			$ciyashop_redux_fields = $ciyashop_redux_fields[$ciyashop_globals['options_name']];
			$fields_count = ( Redux_Helpers::isWpDebug() ) ? count($ciyashop_redux_fields) + 2 : count($ciyashop_redux_fields) + 1;

			$ciyashop_redux_sections['import/export'] = array(
				'title'    => 'Import / Export',
				'desc'     => '',
				'id'       => 'import/export',
				'icon'     => 'el el-refresh',
				'priority' => $sections_count
			);

			$ciyashop_redux_fields['redux_import_export'] = array(
				'id'         => 'redux_import_export',
				'type'       => 'import_export',
				'full_width' => '1',
				'section_id' => 'import/export',
				'priority'   => $fields_count
			);

			$ciyashop_redux_fields_new = array();

			if(!empty( $ciyashop_redux_fields ) && is_array($ciyashop_redux_fields) ){
				foreach( $ciyashop_redux_fields as $ciyashop_redux_field_k => $ciyashop_redux_field_data ){
					$ciyashop_redux_fields_new[$ciyashop_redux_field_data['section_id']][] = $ciyashop_redux_field_data;
				}
			}

			if(!empty( $ciyashop_redux_sections ) && is_array($ciyashop_redux_sections) ){

				$section_id = 0;
				$index      = 0;

				$current_icon = '';

				foreach ($ciyashop_redux_sections as $section) {

					if( isset( $section['title'] ) ) {
						$option_fields[$index]['title']     = $section['title'];
						$option_fields[$index]['id']        = $section['id'];
						$option_fields[$index]['path']      = $section['title'];
						$option_fields[$index]['section_id']= $section['priority'];

						if( isset($section['icon'] ) ){
							$current_icon = $option_fields[$index]['icon'] = $section['icon'];
						}else{
							$option_fields[$index]['icon'] = $current_icon;
						}

						$index++;

						$section_fields = array();
						if( isset($ciyashop_redux_fields_new[$section['id']]) ){
							$section_fields = $ciyashop_redux_fields_new[$section['id']];
							foreach( $section_fields as $field ){
								$field_title = isset($field['title']) ? trim($field['title']) : false;
								if( $field_title ){
									$option_fields[$index]['title'] = $field['title'];
									$option_fields[$index]['id'] = $field['id'];
									$option_fields[$index]['path'] = $section['title'].' &raquo; '.$field['title'];
									$option_fields[$index]['section_id'] = $section['priority'];

									if( isset( $section['icon'] ) ){
										$option_fields[$index]['icon'] = $section['icon'];
									}else{
										$option_fields[$index]['icon'] = $current_icon;
									}
									$index++;
								}
							}
						}
					}
				}
			}

			$localize_data['search_option_placeholder_text'] = esc_js(__('Search for Theme options', 'ciyashop'));
			$localize_data['reduxThemeOptions'] = $option_fields;

			/**
			 * Filters the list of theme option search items.
			 *
			 * @param     array       $localize_data      Theme option search localize data.
			 * 
			 * @visible false
			 * @ignore
			 */
			return apply_filters( 'ciyashop_admin_search_options_localize_data', $localize_data );
		}
	}
}

if( ! function_exists( 'ciyashop_iconpicker_icons' ) ) {
	function ciyashop_iconpicker_icons() {
			
		$fontawesome_icons = array(
			'New in 4.7' => array(
				array( 'fa fa-handshake-o' => 'Handshake Outlined' ),
				array( 'fa fa-envelope-open' => 'Envelope Open(email, e-mail, letter, support, mail, message, notification)' ),
				array( 'fa fa-envelope-open-o' => 'Envelope Open Outlined(email, e-mail, letter, support, mail, message, notification)' ),
				array( 'fa fa-linode' => 'Linode' ),
				array( 'fa fa-address-book' => 'Address Book' ),
				array( 'fa fa-address-book-o' => 'Address Book Outlined' ),
				array( 'fa fa-address-card' => 'Address Card(vcard)' ),
				array( 'fa fa-address-card-o' => 'Address Card Outlined(vcard-o)' ),
				array( 'fa fa-user-circle' => 'User Circle' ),
				array( 'fa fa-user-circle-o' => 'User Circle Outlined' ),
				array( 'fa fa-user-o' => 'User Outlined' ),
				array( 'fa fa-id-badge' => 'Identification Badge' ),
				array( 'fa fa-id-card' => 'Identification Card(drivers-license)' ),
				array( 'fa fa-id-card-o' => 'Identification Card Outlined(drivers-license-o)' ),
				array( 'fa fa-quora' => 'Quora' ),
				array( 'fa fa-free-code-camp' => 'Free Code Camp' ),
				array( 'fa fa-telegram' => 'Telegram' ),
				array( 'fa fa-thermometer-full' => 'Thermometer Full(thermometer-4, thermometer)' ),
				array( 'fa fa-thermometer-three-quarters' => 'Thermometer 3/4 Full(thermometer-3)' ),
				array( 'fa fa-thermometer-half' => 'Thermometer 1/2 Full(thermometer-2)' ),
				array( 'fa fa-thermometer-quarter' => 'Thermometer 1/4 Full(thermometer-1)' ),
				array( 'fa fa-thermometer-empty' => 'Thermometer Empty(thermometer-0)' ),
				array( 'fa fa-shower' => 'Shower' ),
				array( 'fa fa-bath' => 'Bath(bathtub, s15)' ),
				array( 'fa fa-podcast' => 'Podcast' ),
				array( 'fa fa-window-maximize' => 'Window Maximize' ),
				array( 'fa fa-window-minimize' => 'Window Minimize' ),
				array( 'fa fa-window-restore' => 'Window Restore' ),
				array( 'fa fa-window-close' => 'Window Close(times-rectangle)' ),
				array( 'fa fa-window-close-o' => 'Window Close Outline(times-rectangle-o)' ),
				array( 'fa fa-bandcamp' => 'Bandcamp' ),
				array( 'fa fa-grav' => 'Grav' ),
				array( 'fa fa-etsy' => 'Etsy' ),
				array( 'fa fa-imdb' => 'IMDB' ),
				array( 'fa fa-ravelry' => 'Ravelry' ),
				array( 'fa fa-eercast' => 'Eercast' ),
				array( 'fa fa-microchip' => 'Microchip' ),
				array( 'fa fa-snowflake-o' => 'Snowflake Outlined' ),
				array( 'fa fa-superpowers' => 'Superpowers' ),
				array( 'fa fa-wpexplorer' => 'WPExplorer' ),
				array( 'fa fa-meetup' => 'Meetup' ),
			),
			'Web Application Icons' => array(
				array( 'fa fa-glass' => 'Glass(martini, drink, bar, alcohol, liquor)' ),
				array( 'fa fa-music' => 'Music(note, sound)' ),
				array( 'fa fa-search' => 'Search(magnify, zoom, enlarge, bigger)' ),
				array( 'fa fa-envelope-o' => 'Envelope Outlined(email, e-mail, letter, support, mail, message, notification)' ),
				array( 'fa fa-heart' => 'Heart(love, like, favorite)' ),
				array( 'fa fa-star' => 'Star(award, achievement, night, rating, score, favorite)' ),
				array( 'fa fa-star-o' => 'Star Outlined(award, achievement, night, rating, score, favorite)' ),
				array( 'fa fa-user' => 'User(person, man, head, profile)' ),
				array( 'fa fa-film' => 'Film(movie)' ),
				array( 'fa fa-check' => 'Check(checkmark, done, todo, agree, accept, confirm, tick, ok)' ),
				array( 'fa fa-times' => 'Times(close, exit, x, cross)(remove, close)' ),
				array( 'fa fa-search-plus' => 'Search Plus(magnify, zoom, enlarge, bigger)' ),
				array( 'fa fa-search-minus' => 'Search Minus(magnify, minify, zoom, smaller)' ),
				array( 'fa fa-power-off' => 'Power Off(on)' ),
				array( 'fa fa-signal' => 'signal(graph, bars)' ),
				array( 'fa fa-cog' => 'cog(settings)(gear)' ),
				array( 'fa fa-trash-o' => 'Trash Outlined(garbage, delete, remove, trash, hide)' ),
				array( 'fa fa-home' => 'home(main, house)' ),
				array( 'fa fa-clock-o' => 'Clock Outlined(watch, timer, late, timestamp)' ),
				array( 'fa fa-road' => 'road(street)' ),
				array( 'fa fa-download' => 'Download(import)' ),
				array( 'fa fa-inbox' => 'inbox' ),
				array( 'fa fa-refresh' => 'refresh(reload, sync)' ),
				array( 'fa fa-lock' => 'lock(protect, admin, security)' ),
				array( 'fa fa-flag' => 'flag(report, notification, notify)' ),
				array( 'fa fa-headphones' => 'headphones(sound, listen, music, audio)' ),
				array( 'fa fa-volume-off' => 'volume-off(audio, mute, sound, music)' ),
				array( 'fa fa-volume-down' => 'volume-down(audio, lower, quieter, sound, music)' ),
				array( 'fa fa-volume-up' => 'volume-up(audio, higher, louder, sound, music)' ),
				array( 'fa fa-qrcode' => 'qrcode(scan)' ),
				array( 'fa fa-barcode' => 'barcode(scan)' ),
				array( 'fa fa-tag' => 'tag(label)' ),
				array( 'fa fa-tags' => 'tags(labels)' ),
				array( 'fa fa-book' => 'book(read, documentation)' ),
				array( 'fa fa-bookmark' => 'bookmark(save)' ),
				array( 'fa fa-print' => 'print' ),
				array( 'fa fa-camera' => 'camera(photo, picture, record)' ),
				array( 'fa fa-video-camera' => 'Video Camera(film, movie, record)' ),
				array( 'fa fa-picture-o' => 'Picture Outlined(photo, image)' ),
				array( 'fa fa-pencil' => 'pencil(write, edit, update)' ),
				array( 'fa fa-map-marker' => 'map-marker(map, pin, location, coordinates, localize, address, travel, where, place)' ),
				array( 'fa fa-adjust' => 'adjust(contrast)' ),
				array( 'fa fa-tint' => 'tint(raindrop, waterdrop, drop, droplet)' ),
				array( 'fa fa-pencil-square-o' => 'Pencil Square Outlined(write, edit, update)(edit)' ),
				array( 'fa fa-share-square-o' => 'Share Square Outlined(social, send, arrow)' ),
				array( 'fa fa-check-square-o' => 'Check Square Outlined(todo, done, agree, accept, confirm, ok)' ),
				array( 'fa fa-arrows' => 'Arrows(move, reorder, resize)' ),
				array( 'fa fa-plus-circle' => 'Plus Circle(add, new, create, expand)' ),
				array( 'fa fa-minus-circle' => 'Minus Circle(delete, remove, trash, hide)' ),
				array( 'fa fa-times-circle' => 'Times Circle(close, exit, x)' ),
				array( 'fa fa-check-circle' => 'Check Circle(todo, done, agree, accept, confirm, ok)' ),
				array( 'fa fa-question-circle' => 'Question Circle(help, information, unknown, support)' ),
				array( 'fa fa-info-circle' => 'Info Circle(help, information, more, details)' ),
				array( 'fa fa-crosshairs' => 'Crosshairs(picker)' ),
				array( 'fa fa-times-circle-o' => 'Times Circle Outlined(close, exit, x)' ),
				array( 'fa fa-check-circle-o' => 'Check Circle Outlined(todo, done, agree, accept, confirm, ok)' ),
				array( 'fa fa-ban' => 'ban(delete, remove, trash, hide, block, stop, abort, cancel)' ),
				array( 'fa fa-share' => 'Share(mail-forward)' ),
				array( 'fa fa-plus' => 'plus(add, new, create, expand)' ),
				array( 'fa fa-minus' => 'minus(hide, minify, delete, remove, trash, hide, collapse)' ),
				array( 'fa fa-asterisk' => 'asterisk(details)' ),
				array( 'fa fa-exclamation-circle' => 'Exclamation Circle(warning, error, problem, notification, alert)' ),
				array( 'fa fa-gift' => 'gift(present)' ),
				array( 'fa fa-leaf' => 'leaf(eco, nature, plant)' ),
				array( 'fa fa-fire' => 'fire(flame, hot, popular)' ),
				array( 'fa fa-eye' => 'Eye(show, visible, views)' ),
				array( 'fa fa-eye-slash' => 'Eye Slash(toggle, show, hide, visible, visiblity, views)' ),
				array( 'fa fa-exclamation-triangle' => 'Exclamation Triangle(warning, error, problem, notification, alert)(warning)' ),
				array( 'fa fa-plane' => 'plane(travel, trip, location, destination, airplane, fly, mode)' ),
				array( 'fa fa-calendar' => 'calendar(date, time, when, event)' ),
				array( 'fa fa-random' => 'random(sort, shuffle)' ),
				array( 'fa fa-comment' => 'comment(speech, notification, note, chat, bubble, feedback, message, texting, sms, conversation)' ),
				array( 'fa fa-magnet' => 'magnet' ),
				array( 'fa fa-retweet' => 'retweet(refresh, reload, share)' ),
				array( 'fa fa-shopping-cart' => 'shopping-cart(checkout, buy, purchase, payment)' ),
				array( 'fa fa-folder' => 'Folder' ),
				array( 'fa fa-folder-open' => 'Folder Open' ),
				array( 'fa fa-arrows-v' => 'Arrows Vertical(resize)' ),
				array( 'fa fa-arrows-h' => 'Arrows Horizontal(resize)' ),
				array( 'fa fa-bar-chart' => 'Bar Chart(graph, analytics, statistics)(bar-chart-o)' ),
				array( 'fa fa-camera-retro' => 'camera-retro(photo, picture, record)' ),
				array( 'fa fa-key' => 'key(unlock, password)' ),
				array( 'fa fa-cogs' => 'cogs(settings)(gears)' ),
				array( 'fa fa-comments' => 'comments(speech, notification, note, chat, bubble, feedback, message, texting, sms, conversation)' ),
				array( 'fa fa-thumbs-o-up' => 'Thumbs Up Outlined(like, approve, favorite, agree, hand)' ),
				array( 'fa fa-thumbs-o-down' => 'Thumbs Down Outlined(dislike, disapprove, disagree, hand)' ),
				array( 'fa fa-star-half' => 'star-half(award, achievement, rating, score)' ),
				array( 'fa fa-heart-o' => 'Heart Outlined(love, like, favorite)' ),
				array( 'fa fa-sign-out' => 'Sign Out(log out, logout, leave, exit, arrow)' ),
				array( 'fa fa-thumb-tack' => 'Thumb Tack(marker, pin, location, coordinates)' ),
				array( 'fa fa-external-link' => 'External Link(open, new)' ),
				array( 'fa fa-sign-in' => 'Sign In(enter, join, log in, login, sign up, sign in, signin, signup, arrow)' ),
				array( 'fa fa-trophy' => 'trophy(award, achievement, cup, winner, game)' ),
				array( 'fa fa-upload' => 'Upload(import)' ),
				array( 'fa fa-lemon-o' => 'Lemon Outlined(food)' ),
				array( 'fa fa-phone' => 'Phone(call, voice, number, support, earphone, telephone)' ),
				array( 'fa fa-square-o' => 'Square Outlined(block, square, box)' ),
				array( 'fa fa-bookmark-o' => 'Bookmark Outlined(save)' ),
				array( 'fa fa-phone-square' => 'Phone Square(call, voice, number, support, telephone)' ),
				array( 'fa fa-unlock' => 'unlock(protect, admin, password, lock)' ),
				array( 'fa fa-credit-card' => 'credit-card(money, buy, debit, checkout, purchase, payment)' ),
				array( 'fa fa-rss' => 'rss(blog)(feed)' ),
				array( 'fa fa-hdd-o' => 'HDD(harddrive, hard drive, storage, save)' ),
				array( 'fa fa-bullhorn' => 'bullhorn(announcement, share, broadcast, louder, megaphone)' ),
				array( 'fa fa-bell' => 'bell(alert, reminder, notification)' ),
				array( 'fa fa-certificate' => 'certificate(badge, star)' ),
				array( 'fa fa-globe' => 'Globe(world, planet, map, place, travel, earth, global, translate, all, language, localize, location, coordinates, country)' ),
				array( 'fa fa-wrench' => 'Wrench(settings, fix, update, spanner)' ),
				array( 'fa fa-tasks' => 'Tasks(progress, loading, downloading, downloads, settings)' ),
				array( 'fa fa-filter' => 'Filter(funnel, options)' ),
				array( 'fa fa-briefcase' => 'Briefcase(work, business, office, luggage, bag)' ),
				array( 'fa fa-users' => 'Users(people, profiles, persons)(group)' ),
				array( 'fa fa-cloud' => 'Cloud(save)' ),
				array( 'fa fa-flask' => 'Flask(science, beaker, experimental, labs)' ),
				array( 'fa fa-square' => 'Square(block, box)' ),
				array( 'fa fa-bars' => 'Bars(menu, drag, reorder, settings, list, ul, ol, checklist, todo, list, hamburger)(navicon, reorder)' ),
				array( 'fa fa-magic' => 'magic(wizard, automatic, autocomplete)' ),
				array( 'fa fa-truck' => 'truck(shipping)' ),
				array( 'fa fa-money' => 'Money(cash, money, buy, checkout, purchase, payment)' ),
				array( 'fa fa-sort' => 'Sort(order)(unsorted)' ),
				array( 'fa fa-sort-desc' => 'Sort Descending(dropdown, more, menu, arrow)(sort-down)' ),
				array( 'fa fa-sort-asc' => 'Sort Ascending(arrow)(sort-up)' ),
				array( 'fa fa-envelope' => 'Envelope(email, e-mail, letter, support, mail, message, notification)' ),
				array( 'fa fa-gavel' => 'Gavel(judge, lawyer, opinion)(legal)' ),
				array( 'fa fa-tachometer' => 'Tachometer(speedometer, fast)(dashboard)' ),
				array( 'fa fa-comment-o' => 'comment-o(speech, notification, note, chat, bubble, feedback, message, texting, sms, conversation)' ),
				array( 'fa fa-comments-o' => 'comments-o(speech, notification, note, chat, bubble, feedback, message, texting, sms, conversation)' ),
				array( 'fa fa-bolt' => 'Lightning Bolt(lightning, weather)(flash)' ),
				array( 'fa fa-sitemap' => 'Sitemap(directory, hierarchy, organization)' ),
				array( 'fa fa-umbrella' => 'Umbrella' ),
				array( 'fa fa-lightbulb-o' => 'Lightbulb Outlined(idea, inspiration)' ),
				array( 'fa fa-exchange' => 'Exchange(transfer, arrows, arrow)' ),
				array( 'fa fa-cloud-download' => 'Cloud Download(import)' ),
				array( 'fa fa-cloud-upload' => 'Cloud Upload(import)' ),
				array( 'fa fa-suitcase' => 'Suitcase(trip, luggage, travel, move, baggage)' ),
				array( 'fa fa-bell-o' => 'Bell Outlined(alert, reminder, notification)' ),
				array( 'fa fa-coffee' => 'Coffee(morning, mug, breakfast, tea, drink, cafe)' ),
				array( 'fa fa-cutlery' => 'Cutlery(food, restaurant, spoon, knife, dinner, eat)' ),
				array( 'fa fa-building-o' => 'Building Outlined(work, business, apartment, office, company)' ),
				array( 'fa fa-fighter-jet' => 'fighter-jet(fly, plane, airplane, quick, fast, travel)' ),
				array( 'fa fa-beer' => 'beer(alcohol, stein, drink, mug, bar, liquor)' ),
				array( 'fa fa-plus-square' => 'Plus Square(add, new, create, expand)' ),
				array( 'fa fa-desktop' => 'Desktop(monitor, screen, desktop, computer, demo, device)' ),
				array( 'fa fa-laptop' => 'Laptop(demo, computer, device)' ),
				array( 'fa fa-tablet' => 'tablet(ipad, device)' ),
				array( 'fa fa-mobile' => 'Mobile Phone(cell phone, cellphone, text, call, iphone, number, telephone)(mobile-phone)' ),
				array( 'fa fa-circle-o' => 'Circle Outlined' ),
				array( 'fa fa-quote-left' => 'quote-left' ),
				array( 'fa fa-quote-right' => 'quote-right' ),
				array( 'fa fa-spinner' => 'Spinner(loading, progress)' ),
				array( 'fa fa-circle' => 'Circle(dot, notification)' ),
				array( 'fa fa-reply' => 'Reply(mail-reply)' ),
				array( 'fa fa-folder-o' => 'Folder Outlined' ),
				array( 'fa fa-folder-open-o' => 'Folder Open Outlined' ),
				array( 'fa fa-smile-o' => 'Smile Outlined(face, emoticon, happy, approve, satisfied, rating)' ),
				array( 'fa fa-frown-o' => 'Frown Outlined(face, emoticon, sad, disapprove, rating)' ),
				array( 'fa fa-meh-o' => 'Meh Outlined(face, emoticon, rating, neutral)' ),
				array( 'fa fa-gamepad' => 'Gamepad(controller)' ),
				array( 'fa fa-keyboard-o' => 'Keyboard Outlined(type, input)' ),
				array( 'fa fa-flag-o' => 'Flag Outlined(report, notification)' ),
				array( 'fa fa-flag-checkered' => 'flag-checkered(report, notification, notify)' ),
				array( 'fa fa-terminal' => 'Terminal(command, prompt, code)' ),
				array( 'fa fa-code' => 'Code(html, brackets)' ),
				array( 'fa fa-reply-all' => 'reply-all(mail-reply-all)' ),
				array( 'fa fa-star-half-o' => 'Star Half Outlined(award, achievement, rating, score)(star-half-empty, star-half-full)' ),
				array( 'fa fa-location-arrow' => 'location-arrow(map, coordinates, location, address, place, where)' ),
				array( 'fa fa-crop' => 'crop' ),
				array( 'fa fa-code-fork' => 'code-fork(git, fork, vcs, svn, github, rebase, version, merge)' ),
				array( 'fa fa-question' => 'Question(help, information, unknown, support)' ),
				array( 'fa fa-info' => 'Info(help, information, more, details)' ),
				array( 'fa fa-exclamation' => 'exclamation(warning, error, problem, notification, notify, alert)' ),
				array( 'fa fa-eraser' => 'eraser(remove, delete)' ),
				array( 'fa fa-puzzle-piece' => 'Puzzle Piece(addon, add-on, section)' ),
				array( 'fa fa-microphone' => 'microphone(record, voice, sound)' ),
				array( 'fa fa-microphone-slash' => 'Microphone Slash(record, voice, sound, mute)' ),
				array( 'fa fa-shield' => 'shield(award, achievement, security, winner)' ),
				array( 'fa fa-calendar-o' => 'calendar-o(date, time, when, event)' ),
				array( 'fa fa-fire-extinguisher' => 'fire-extinguisher' ),
				array( 'fa fa-rocket' => 'rocket(app)' ),
				array( 'fa fa-anchor' => 'Anchor(link)' ),
				array( 'fa fa-unlock-alt' => 'Unlock Alt(protect, admin, password, lock)' ),
				array( 'fa fa-bullseye' => 'Bullseye(target)' ),
				array( 'fa fa-ellipsis-h' => 'Ellipsis Horizontal(dots)' ),
				array( 'fa fa-ellipsis-v' => 'Ellipsis Vertical(dots)' ),
				array( 'fa fa-rss-square' => 'RSS Square(feed, blog)' ),
				array( 'fa fa-ticket' => 'Ticket(movie, pass, support)' ),
				array( 'fa fa-minus-square' => 'Minus Square(hide, minify, delete, remove, trash, hide, collapse)' ),
				array( 'fa fa-minus-square-o' => 'Minus Square Outlined(hide, minify, delete, remove, trash, hide, collapse)' ),
				array( 'fa fa-level-up' => 'Level Up(arrow)' ),
				array( 'fa fa-level-down' => 'Level Down(arrow)' ),
				array( 'fa fa-check-square' => 'Check Square(checkmark, done, todo, agree, accept, confirm, ok)' ),
				array( 'fa fa-pencil-square' => 'Pencil Square(write, edit, update)' ),
				array( 'fa fa-external-link-square' => 'External Link Square(open, new)' ),
				array( 'fa fa-share-square' => 'Share Square(social, send)' ),
				array( 'fa fa-compass' => 'Compass(safari, directory, menu, location)' ),
				array( 'fa fa-caret-square-o-down' => 'Caret Square Outlined Down(more, dropdown, menu)(toggle-down)' ),
				array( 'fa fa-caret-square-o-up' => 'Caret Square Outlined Up(toggle-up)' ),
				array( 'fa fa-caret-square-o-right' => 'Caret Square Outlined Right(next, forward)(toggle-right)' ),
				array( 'fa fa-sort-alpha-asc' => 'Sort Alpha Ascending' ),
				array( 'fa fa-sort-alpha-desc' => 'Sort Alpha Descending' ),
				array( 'fa fa-sort-amount-asc' => 'Sort Amount Ascending' ),
				array( 'fa fa-sort-amount-desc' => 'Sort Amount Descending' ),
				array( 'fa fa-sort-numeric-asc' => 'Sort Numeric Ascending(numbers)' ),
				array( 'fa fa-sort-numeric-desc' => 'Sort Numeric Descending(numbers)' ),
				array( 'fa fa-thumbs-up' => 'thumbs-up(like, favorite, approve, agree, hand)' ),
				array( 'fa fa-thumbs-down' => 'thumbs-down(dislike, disapprove, disagree, hand)' ),
				array( 'fa fa-female' => 'Female(woman, user, person, profile)' ),
				array( 'fa fa-male' => 'Male(man, user, person, profile)' ),
				array( 'fa fa-sun-o' => 'Sun Outlined(weather, contrast, lighter, brighten, day)' ),
				array( 'fa fa-moon-o' => 'Moon Outlined(night, darker, contrast)' ),
				array( 'fa fa-archive' => 'Archive(box, storage)' ),
				array( 'fa fa-bug' => 'Bug(report, insect)' ),
				array( 'fa fa-caret-square-o-left' => 'Caret Square Outlined Left(previous, back)(toggle-left)' ),
				array( 'fa fa-dot-circle-o' => 'Dot Circle Outlined(target, bullseye, notification)' ),
				array( 'fa fa-wheelchair' => 'Wheelchair(handicap, person)' ),
				array( 'fa fa-plus-square-o' => 'Plus Square Outlined(add, new, create, expand)' ),
				array( 'fa fa-space-shuttle' => 'Space Shuttle' ),
				array( 'fa fa-envelope-square' => 'Envelope Square(email, e-mail, letter, support, mail, message, notification)' ),
				array( 'fa fa-university' => 'University(institution, bank)' ),
				array( 'fa fa-graduation-cap' => 'Graduation Cap(learning, school, student)(mortar-board)' ),
				array( 'fa fa-language' => 'Language(translate)' ),
				array( 'fa fa-fax' => 'Fax' ),
				array( 'fa fa-building' => 'Building(work, business, apartment, office, company)' ),
				array( 'fa fa-child' => 'Child' ),
				array( 'fa fa-paw' => 'Paw(pet)' ),
				array( 'fa fa-spoon' => 'spoon' ),
				array( 'fa fa-cube' => 'Cube' ),
				array( 'fa fa-cubes' => 'Cubes' ),
				array( 'fa fa-recycle' => 'Recycle' ),
				array( 'fa fa-car' => 'Car(vehicle)(automobile)' ),
				array( 'fa fa-taxi' => 'Taxi(vehicle)(cab)' ),
				array( 'fa fa-tree' => 'Tree' ),
				array( 'fa fa-database' => 'Database' ),
				array( 'fa fa-file-pdf-o' => 'PDF File Outlined' ),
				array( 'fa fa-file-word-o' => 'Word File Outlined' ),
				array( 'fa fa-file-excel-o' => 'Excel File Outlined' ),
				array( 'fa fa-file-powerpoint-o' => 'Powerpoint File Outlined' ),
				array( 'fa fa-file-image-o' => 'Image File Outlined(file-photo-o, file-picture-o)' ),
				array( 'fa fa-file-archive-o' => 'Archive File Outlined(file-zip-o)' ),
				array( 'fa fa-file-audio-o' => 'Audio File Outlined(file-sound-o)' ),
				array( 'fa fa-file-video-o' => 'Video File Outlined(file-movie-o)' ),
				array( 'fa fa-file-code-o' => 'Code File Outlined' ),
				array( 'fa fa-life-ring' => 'Life Ring(life-bouy, life-buoy, life-saver, support)' ),
				array( 'fa fa-circle-o-notch' => 'Circle Outlined Notched' ),
				array( 'fa fa-paper-plane' => 'Paper Plane(send)' ),
				array( 'fa fa-paper-plane-o' => 'Paper Plane Outlined(send-o)' ),
				array( 'fa fa-history' => 'History' ),
				array( 'fa fa-circle-thin' => 'Circle Outlined Thin' ),
				array( 'fa fa-sliders' => 'Sliders(settings)' ),
				array( 'fa fa-share-alt' => 'Share Alt' ),
				array( 'fa fa-share-alt-square' => 'Share Alt Square' ),
				array( 'fa fa-bomb' => 'Bomb' ),
				array( 'fa fa-futbol-o' => 'Futbol Outlined(soccer-ball-o)' ),
				array( 'fa fa-tty' => 'TTY' ),
				array( 'fa fa-binoculars' => 'Binoculars' ),
				array( 'fa fa-plug' => 'Plug(power, connect)' ),
				array( 'fa fa-newspaper-o' => 'Newspaper Outlined(press)' ),
				array( 'fa fa-wifi' => 'WiFi' ),
				array( 'fa fa-calculator' => 'Calculator' ),
				array( 'fa fa-bell-slash' => 'Bell Slash' ),
				array( 'fa fa-bell-slash-o' => 'Bell Slash Outlined' ),
				array( 'fa fa-trash' => 'Trash(garbage, delete, remove, hide)' ),
				array( 'fa fa-copyright' => 'Copyright' ),
				array( 'fa fa-at' => 'At(email, e-mail)' ),
				array( 'fa fa-eyedropper' => 'Eyedropper' ),
				array( 'fa fa-paint-brush' => 'Paint Brush' ),
				array( 'fa fa-birthday-cake' => 'Birthday Cake' ),
				array( 'fa fa-area-chart' => 'Area Chart(graph, analytics, statistics)' ),
				array( 'fa fa-pie-chart' => 'Pie Chart(graph, analytics, statistics)' ),
				array( 'fa fa-line-chart' => 'Line Chart(graph, analytics, statistics)' ),
				array( 'fa fa-toggle-off' => 'Toggle Off' ),
				array( 'fa fa-toggle-on' => 'Toggle On' ),
				array( 'fa fa-bicycle' => 'Bicycle(vehicle, bike)' ),
				array( 'fa fa-bus' => 'Bus(vehicle)' ),
				array( 'fa fa-cc' => 'Closed Captions' ),
				array( 'fa fa-cart-plus' => 'Add to Shopping Cart(add, shopping)' ),
				array( 'fa fa-cart-arrow-down' => 'Shopping Cart Arrow Down(shopping)' ),
				array( 'fa fa-diamond' => 'Diamond(gem, gemstone)' ),
				array( 'fa fa-ship' => 'Ship(boat, sea)' ),
				array( 'fa fa-user-secret' => 'User Secret(whisper, spy, incognito, privacy)' ),
				array( 'fa fa-motorcycle' => 'Motorcycle(vehicle, bike)' ),
				array( 'fa fa-street-view' => 'Street View(map)' ),
				array( 'fa fa-heartbeat' => 'Heartbeat(ekg)' ),
				array( 'fa fa-server' => 'Server' ),
				array( 'fa fa-user-plus' => 'Add User(sign up, signup)' ),
				array( 'fa fa-user-times' => 'Remove User' ),
				array( 'fa fa-bed' => 'Bed(travel)(hotel)' ),
				array( 'fa fa-battery-full' => 'Battery Full(power)(battery-4, battery)' ),
				array( 'fa fa-battery-three-quarters' => 'Battery 3/4 Full(power)(battery-3)' ),
				array( 'fa fa-battery-half' => 'Battery 1/2 Full(power)(battery-2)' ),
				array( 'fa fa-battery-quarter' => 'Battery 1/4 Full(power)(battery-1)' ),
				array( 'fa fa-battery-empty' => 'Battery Empty(power)(battery-0)' ),
				array( 'fa fa-mouse-pointer' => 'Mouse Pointer' ),
				array( 'fa fa-i-cursor' => 'I Beam Cursor' ),
				array( 'fa fa-object-group' => 'Object Group' ),
				array( 'fa fa-object-ungroup' => 'Object Ungroup' ),
				array( 'fa fa-sticky-note' => 'Sticky Note' ),
				array( 'fa fa-sticky-note-o' => 'Sticky Note Outlined' ),
				array( 'fa fa-clone' => 'Clone(copy)' ),
				array( 'fa fa-balance-scale' => 'Balance Scale' ),
				array( 'fa fa-hourglass-o' => 'Hourglass Outlined' ),
				array( 'fa fa-hourglass-start' => 'Hourglass Start(hourglass-1)' ),
				array( 'fa fa-hourglass-half' => 'Hourglass Half(hourglass-2)' ),
				array( 'fa fa-hourglass-end' => 'Hourglass End(hourglass-3)' ),
				array( 'fa fa-hourglass' => 'Hourglass' ),
				array( 'fa fa-hand-rock-o' => 'Rock (Hand)(hand-grab-o)' ),
				array( 'fa fa-hand-paper-o' => 'Paper (Hand)(stop)(hand-stop-o)' ),
				array( 'fa fa-hand-scissors-o' => 'Scissors (Hand)' ),
				array( 'fa fa-hand-lizard-o' => 'Lizard (Hand)' ),
				array( 'fa fa-hand-spock-o' => 'Spock (Hand)' ),
				array( 'fa fa-hand-pointer-o' => 'Hand Pointer' ),
				array( 'fa fa-hand-peace-o' => 'Hand Peace' ),
				array( 'fa fa-trademark' => 'Trademark' ),
				array( 'fa fa-registered' => 'Registered Trademark' ),
				array( 'fa fa-creative-commons' => 'Creative Commons' ),
				array( 'fa fa-television' => 'Television(display, computer, monitor)(tv)' ),
				array( 'fa fa-calendar-plus-o' => 'Calendar Plus Outlined' ),
				array( 'fa fa-calendar-minus-o' => 'Calendar Minus Outlined' ),
				array( 'fa fa-calendar-times-o' => 'Calendar Times Outlined' ),
				array( 'fa fa-calendar-check-o' => 'Calendar Check Outlined(ok)' ),
				array( 'fa fa-industry' => 'Industry(factory)' ),
				array( 'fa fa-map-pin' => 'Map Pin' ),
				array( 'fa fa-map-signs' => 'Map Signs' ),
				array( 'fa fa-map-o' => 'Map Outlined' ),
				array( 'fa fa-map' => 'Map' ),
				array( 'fa fa-commenting' => 'Commenting(speech, notification, note, chat, bubble, feedback, message, texting, sms, conversation)' ),
				array( 'fa fa-commenting-o' => 'Commenting Outlined(speech, notification, note, chat, bubble, feedback, message, texting, sms, conversation)' ),
				array( 'fa fa-credit-card-alt' => 'Credit Card(money, buy, debit, checkout, purchase, payment, credit card)' ),
				array( 'fa fa-shopping-bag' => 'Shopping Bag' ),
				array( 'fa fa-shopping-basket' => 'Shopping Basket' ),
				array( 'fa fa-hashtag' => 'Hashtag' ),
				array( 'fa fa-bluetooth' => 'Bluetooth' ),
				array( 'fa fa-bluetooth-b' => 'Bluetooth' ),
				array( 'fa fa-percent' => 'Percent' ),
				array( 'fa fa-universal-access' => 'Universal Access' ),
				array( 'fa fa-wheelchair-alt' => 'Wheelchair Alt(handicap, person)' ),
				array( 'fa fa-question-circle-o' => 'Question Circle Outlined' ),
				array( 'fa fa-blind' => 'Blind' ),
				array( 'fa fa-audio-description' => 'Audio Description' ),
				array( 'fa fa-volume-control-phone' => 'Volume Control Phone(telephone)' ),
				array( 'fa fa-braille' => 'Braille' ),
				array( 'fa fa-assistive-listening-systems' => 'Assistive Listening Systems' ),
				array( 'fa fa-american-sign-language-interpreting' => 'American Sign Language Interpreting(asl-interpreting)' ),
				array( 'fa fa-deaf' => 'Deaf(deafness, hard-of-hearing)' ),
				array( 'fa fa-sign-language' => 'Sign Language(signing)' ),
				array( 'fa fa-low-vision' => 'Low Vision' ),
				array( 'fa fa-handshake-o' => 'Handshake Outlined' ),
				array( 'fa fa-envelope-open' => 'Envelope Open(email, e-mail, letter, support, mail, message, notification)' ),
				array( 'fa fa-envelope-open-o' => 'Envelope Open Outlined(email, e-mail, letter, support, mail, message, notification)' ),
				array( 'fa fa-address-book' => 'Address Book' ),
				array( 'fa fa-address-book-o' => 'Address Book Outlined' ),
				array( 'fa fa-address-card' => 'Address Card(vcard)' ),
				array( 'fa fa-address-card-o' => 'Address Card Outlined(vcard-o)' ),
				array( 'fa fa-user-circle' => 'User Circle' ),
				array( 'fa fa-user-circle-o' => 'User Circle Outlined' ),
				array( 'fa fa-user-o' => 'User Outlined' ),
				array( 'fa fa-id-badge' => 'Identification Badge' ),
				array( 'fa fa-id-card' => 'Identification Card(drivers-license)' ),
				array( 'fa fa-id-card-o' => 'Identification Card Outlined(drivers-license-o)' ),
				array( 'fa fa-thermometer-full' => 'Thermometer Full(thermometer-4, thermometer)' ),
				array( 'fa fa-thermometer-three-quarters' => 'Thermometer 3/4 Full(thermometer-3)' ),
				array( 'fa fa-thermometer-half' => 'Thermometer 1/2 Full(thermometer-2)' ),
				array( 'fa fa-thermometer-quarter' => 'Thermometer 1/4 Full(thermometer-1)' ),
				array( 'fa fa-thermometer-empty' => 'Thermometer Empty(thermometer-0)' ),
				array( 'fa fa-shower' => 'Shower' ),
				array( 'fa fa-bath' => 'Bath(bathtub, s15)' ),
				array( 'fa fa-podcast' => 'Podcast' ),
				array( 'fa fa-window-maximize' => 'Window Maximize' ),
				array( 'fa fa-window-minimize' => 'Window Minimize' ),
				array( 'fa fa-window-restore' => 'Window Restore' ),
				array( 'fa fa-window-close' => 'Window Close(times-rectangle)' ),
				array( 'fa fa-window-close-o' => 'Window Close Outline(times-rectangle-o)' ),
				array( 'fa fa-microchip' => 'Microchip' ),
				array( 'fa fa-snowflake-o' => 'Snowflake Outlined' ),
			),
			'Medical Icons' => array(
				array( 'fa fa-heart' => 'Heart(love, like, favorite)' ),
				array( 'fa fa-heart-o' => 'Heart Outlined(love, like, favorite)' ),
				array( 'fa fa-user-md' => 'user-md(doctor, profile, medical, nurse)' ),
				array( 'fa fa-stethoscope' => 'Stethoscope' ),
				array( 'fa fa-hospital-o' => 'hospital Outlined(building)' ),
				array( 'fa fa-ambulance' => 'ambulance(vehicle, support, help)' ),
				array( 'fa fa-medkit' => 'medkit(first aid, firstaid, help, support, health)' ),
				array( 'fa fa-h-square' => 'H Square(hospital, hotel)' ),
				array( 'fa fa-plus-square' => 'Plus Square(add, new, create, expand)' ),
				array( 'fa fa-wheelchair' => 'Wheelchair(handicap, person)' ),
				array( 'fa fa-heartbeat' => 'Heartbeat(ekg)' ),
				array( 'fa fa-wheelchair-alt' => 'Wheelchair Alt(handicap, person)' ),
			),
			'Text Editor Icons' => array(
				array( 'fa fa-th-large' => 'th-large(blocks, squares, boxes, grid)' ),
				array( 'fa fa-th' => 'th(blocks, squares, boxes, grid)' ),
				array( 'fa fa-th-list' => 'th-list(ul, ol, checklist, finished, completed, done, todo)' ),
				array( 'fa fa-file-o' => 'File Outlined(new, page, pdf, document)' ),
				array( 'fa fa-repeat' => 'Repeat(redo, forward)(rotate-right)' ),
				array( 'fa fa-list-alt' => 'list-alt(ul, ol, checklist, finished, completed, done, todo)' ),
				array( 'fa fa-font' => 'font(text)' ),
				array( 'fa fa-bold' => 'bold' ),
				array( 'fa fa-italic' => 'italic(italics)' ),
				array( 'fa fa-text-height' => 'text-height' ),
				array( 'fa fa-text-width' => 'text-width' ),
				array( 'fa fa-align-left' => 'align-left(text)' ),
				array( 'fa fa-align-center' => 'align-center(middle, text)' ),
				array( 'fa fa-align-right' => 'align-right(text)' ),
				array( 'fa fa-align-justify' => 'align-justify(text)' ),
				array( 'fa fa-list' => 'list(ul, ol, checklist, finished, completed, done, todo)' ),
				array( 'fa fa-outdent' => 'Outdent(dedent)' ),
				array( 'fa fa-indent' => 'Indent' ),
				array( 'fa fa-link' => 'Link(chain)(chain)' ),
				array( 'fa fa-scissors' => 'Scissors(cut)' ),
				array( 'fa fa-files-o' => 'Files Outlined(duplicate, clone, copy)(copy)' ),
				array( 'fa fa-paperclip' => 'Paperclip(attachment)' ),
				array( 'fa fa-floppy-o' => 'Floppy Outlined(save)' ),
				array( 'fa fa-list-ul' => 'list-ul(ul, ol, checklist, todo, list)' ),
				array( 'fa fa-list-ol' => 'list-ol(ul, ol, checklist, list, todo, list, numbers)' ),
				array( 'fa fa-strikethrough' => 'Strikethrough' ),
				array( 'fa fa-underline' => 'Underline' ),
				array( 'fa fa-table' => 'table(data, excel, spreadsheet)' ),
				array( 'fa fa-columns' => 'Columns(split, panes)' ),
				array( 'fa fa-undo' => 'Undo(back)(rotate-left)' ),
				array( 'fa fa-clipboard' => 'Clipboard(copy)(paste)' ),
				array( 'fa fa-file-text-o' => 'File Text Outlined(new, page, pdf, document)' ),
				array( 'fa fa-chain-broken' => 'Chain Broken(remove)(unlink)' ),
				array( 'fa fa-superscript' => 'superscript(exponential)' ),
				array( 'fa fa-subscript' => 'subscript' ),
				array( 'fa fa-eraser' => 'eraser(remove, delete)' ),
				array( 'fa fa-file' => 'File(new, page, pdf, document)' ),
				array( 'fa fa-file-text' => 'File Text(new, page, pdf, document)' ),
				array( 'fa fa-header' => 'header(heading)' ),
				array( 'fa fa-paragraph' => 'paragraph' ),
			),
			'Spinner Icons' => array(
				array( 'fa fa-cog' => 'cog(settings)(gear)' ),
				array( 'fa fa-refresh' => 'refresh(reload, sync)' ),
				array( 'fa fa-spinner' => 'Spinner(loading, progress)' ),
				array( 'fa fa-circle-o-notch' => 'Circle Outlined Notched' ),
			),
			'File Type Icons' => array(
				array( 'fa fa-file-o' => 'File Outlined(new, page, pdf, document)' ),
				array( 'fa fa-file-text-o' => 'File Text Outlined(new, page, pdf, document)' ),
				array( 'fa fa-file' => 'File(new, page, pdf, document)' ),
				array( 'fa fa-file-text' => 'File Text(new, page, pdf, document)' ),
				array( 'fa fa-file-pdf-o' => 'PDF File Outlined' ),
				array( 'fa fa-file-word-o' => 'Word File Outlined' ),
				array( 'fa fa-file-excel-o' => 'Excel File Outlined' ),
				array( 'fa fa-file-powerpoint-o' => 'Powerpoint File Outlined' ),
				array( 'fa fa-file-image-o' => 'Image File Outlined(file-photo-o, file-picture-o)' ),
				array( 'fa fa-file-archive-o' => 'Archive File Outlined(file-zip-o)' ),
				array( 'fa fa-file-audio-o' => 'Audio File Outlined(file-sound-o)' ),
				array( 'fa fa-file-video-o' => 'Video File Outlined(file-movie-o)' ),
				array( 'fa fa-file-code-o' => 'Code File Outlined' ),
			),
			'Directional Icons' => array(
				array( 'fa fa-arrow-circle-o-down' => 'Arrow Circle Outlined Down(download)' ),
				array( 'fa fa-arrow-circle-o-up' => 'Arrow Circle Outlined Up' ),
				array( 'fa fa-arrows' => 'Arrows(move, reorder, resize)' ),
				array( 'fa fa-chevron-left' => 'chevron-left(bracket, previous, back)' ),
				array( 'fa fa-chevron-right' => 'chevron-right(bracket, next, forward)' ),
				array( 'fa fa-arrow-left' => 'arrow-left(previous, back)' ),
				array( 'fa fa-arrow-right' => 'arrow-right(next, forward)' ),
				array( 'fa fa-arrow-up' => 'arrow-up' ),
				array( 'fa fa-arrow-down' => 'arrow-down(download)' ),
				array( 'fa fa-chevron-up' => 'chevron-up' ),
				array( 'fa fa-chevron-down' => 'chevron-down' ),
				array( 'fa fa-arrows-v' => 'Arrows Vertical(resize)' ),
				array( 'fa fa-arrows-h' => 'Arrows Horizontal(resize)' ),
				array( 'fa fa-hand-o-right' => 'Hand Outlined Right(point, right, next, forward, finger)' ),
				array( 'fa fa-hand-o-left' => 'Hand Outlined Left(point, left, previous, back, finger)' ),
				array( 'fa fa-hand-o-up' => 'Hand Outlined Up(point, finger)' ),
				array( 'fa fa-hand-o-down' => 'Hand Outlined Down(point, finger)' ),
				array( 'fa fa-arrow-circle-left' => 'Arrow Circle Left(previous, back)' ),
				array( 'fa fa-arrow-circle-right' => 'Arrow Circle Right(next, forward)' ),
				array( 'fa fa-arrow-circle-up' => 'Arrow Circle Up' ),
				array( 'fa fa-arrow-circle-down' => 'Arrow Circle Down(download)' ),
				array( 'fa fa-arrows-alt' => 'Arrows Alt(expand, enlarge, fullscreen, bigger, move, reorder, resize, arrow)' ),
				array( 'fa fa-caret-down' => 'Caret Down(more, dropdown, menu, triangle down, arrow)' ),
				array( 'fa fa-caret-up' => 'Caret Up(triangle up, arrow)' ),
				array( 'fa fa-caret-left' => 'Caret Left(previous, back, triangle left, arrow)' ),
				array( 'fa fa-caret-right' => 'Caret Right(next, forward, triangle right, arrow)' ),
				array( 'fa fa-exchange' => 'Exchange(transfer, arrows, arrow)' ),
				array( 'fa fa-angle-double-left' => 'Angle Double Left(laquo, quote, previous, back, arrows)' ),
				array( 'fa fa-angle-double-right' => 'Angle Double Right(raquo, quote, next, forward, arrows)' ),
				array( 'fa fa-angle-double-up' => 'Angle Double Up(arrows)' ),
				array( 'fa fa-angle-double-down' => 'Angle Double Down(arrows)' ),
				array( 'fa fa-angle-left' => 'angle-left(previous, back, arrow)' ),
				array( 'fa fa-angle-right' => 'angle-right(next, forward, arrow)' ),
				array( 'fa fa-angle-up' => 'angle-up(arrow)' ),
				array( 'fa fa-angle-down' => 'angle-down(arrow)' ),
				array( 'fa fa-chevron-circle-left' => 'Chevron Circle Left(previous, back, arrow)' ),
				array( 'fa fa-chevron-circle-right' => 'Chevron Circle Right(next, forward, arrow)' ),
				array( 'fa fa-chevron-circle-up' => 'Chevron Circle Up(arrow)' ),
				array( 'fa fa-chevron-circle-down' => 'Chevron Circle Down(more, dropdown, menu, arrow)' ),
				array( 'fa fa-caret-square-o-down' => 'Caret Square Outlined Down(more, dropdown, menu)(toggle-down)' ),
				array( 'fa fa-caret-square-o-up' => 'Caret Square Outlined Up(toggle-up)' ),
				array( 'fa fa-caret-square-o-right' => 'Caret Square Outlined Right(next, forward)(toggle-right)' ),
				array( 'fa fa-long-arrow-down' => 'Long Arrow Down' ),
				array( 'fa fa-long-arrow-up' => 'Long Arrow Up' ),
				array( 'fa fa-long-arrow-left' => 'Long Arrow Left(previous, back)' ),
				array( 'fa fa-long-arrow-right' => 'Long Arrow Right' ),
				array( 'fa fa-arrow-circle-o-right' => 'Arrow Circle Outlined Right(next, forward)' ),
				array( 'fa fa-arrow-circle-o-left' => 'Arrow Circle Outlined Left(previous, back)' ),
				array( 'fa fa-caret-square-o-left' => 'Caret Square Outlined Left(previous, back)(toggle-left)' ),
			),
			'Video Player Icons' => array(
				array( 'fa fa-play-circle-o' => 'Play Circle Outlined' ),
				array( 'fa fa-step-backward' => 'step-backward(rewind, previous, beginning, start, first)' ),
				array( 'fa fa-fast-backward' => 'fast-backward(rewind, previous, beginning, start, first)' ),
				array( 'fa fa-backward' => 'backward(rewind, previous)' ),
				array( 'fa fa-play' => 'play(start, playing, music, sound)' ),
				array( 'fa fa-pause' => 'pause(wait)' ),
				array( 'fa fa-stop' => 'stop(block, box, square)' ),
				array( 'fa fa-forward' => 'forward(forward, next)' ),
				array( 'fa fa-fast-forward' => 'fast-forward(next, end, last)' ),
				array( 'fa fa-step-forward' => 'step-forward(next, end, last)' ),
				array( 'fa fa-eject' => 'eject' ),
				array( 'fa fa-expand' => 'Expand(enlarge, bigger, resize)' ),
				array( 'fa fa-compress' => 'Compress(collapse, combine, contract, merge, smaller)' ),
				array( 'fa fa-random' => 'random(sort, shuffle)' ),
				array( 'fa fa-arrows-alt' => 'Arrows Alt(expand, enlarge, fullscreen, bigger, move, reorder, resize, arrow)' ),
				array( 'fa fa-play-circle' => 'Play Circle(start, playing)' ),
				array( 'fa fa-youtube-play' => 'YouTube Play(start, playing)' ),
				array( 'fa fa-pause-circle' => 'Pause Circle' ),
				array( 'fa fa-pause-circle-o' => 'Pause Circle Outlined' ),
				array( 'fa fa-stop-circle' => 'Stop Circle' ),
				array( 'fa fa-stop-circle-o' => 'Stop Circle Outlined' ),
			),
			'Form Control Icons' => array(
				array( 'fa fa-check-square-o' => 'Check Square Outlined(todo, done, agree, accept, confirm, ok)' ),
				array( 'fa fa-square-o' => 'Square Outlined(block, square, box)' ),
				array( 'fa fa-square' => 'Square(block, box)' ),
				array( 'fa fa-plus-square' => 'Plus Square(add, new, create, expand)' ),
				array( 'fa fa-circle-o' => 'Circle Outlined' ),
				array( 'fa fa-circle' => 'Circle(dot, notification)' ),
				array( 'fa fa-minus-square' => 'Minus Square(hide, minify, delete, remove, trash, hide, collapse)' ),
				array( 'fa fa-minus-square-o' => 'Minus Square Outlined(hide, minify, delete, remove, trash, hide, collapse)' ),
				array( 'fa fa-check-square' => 'Check Square(checkmark, done, todo, agree, accept, confirm, ok)' ),
				array( 'fa fa-dot-circle-o' => 'Dot Circle Outlined(target, bullseye, notification)' ),
				array( 'fa fa-plus-square-o' => 'Plus Square Outlined(add, new, create, expand)' ),
			),
			'Transportation Icons' => array(
				array( 'fa fa-plane' => 'plane(travel, trip, location, destination, airplane, fly, mode)' ),
				array( 'fa fa-truck' => 'truck(shipping)' ),
				array( 'fa fa-ambulance' => 'ambulance(vehicle, support, help)' ),
				array( 'fa fa-fighter-jet' => 'fighter-jet(fly, plane, airplane, quick, fast, travel)' ),
				array( 'fa fa-rocket' => 'rocket(app)' ),
				array( 'fa fa-wheelchair' => 'Wheelchair(handicap, person)' ),
				array( 'fa fa-space-shuttle' => 'Space Shuttle' ),
				array( 'fa fa-car' => 'Car(vehicle)(automobile)' ),
				array( 'fa fa-taxi' => 'Taxi(vehicle)(cab)' ),
				array( 'fa fa-bicycle' => 'Bicycle(vehicle, bike)' ),
				array( 'fa fa-bus' => 'Bus(vehicle)' ),
				array( 'fa fa-ship' => 'Ship(boat, sea)' ),
				array( 'fa fa-motorcycle' => 'Motorcycle(vehicle, bike)' ),
				array( 'fa fa-train' => 'Train' ),
				array( 'fa fa-subway' => 'Subway' ),
				array( 'fa fa-wheelchair-alt' => 'Wheelchair Alt(handicap, person)' ),
			),
			'Chart Icons' => array(
				array( 'fa fa-bar-chart' => 'Bar Chart(graph, analytics, statistics)(bar-chart-o)' ),
				array( 'fa fa-area-chart' => 'Area Chart(graph, analytics, statistics)' ),
				array( 'fa fa-pie-chart' => 'Pie Chart(graph, analytics, statistics)' ),
				array( 'fa fa-line-chart' => 'Line Chart(graph, analytics, statistics)' ),
			),
			'Brand Icons' => array(
				array( 'fa fa-twitter-square' => 'Twitter Square(tweet, social network)' ),
				array( 'fa fa-facebook-square' => 'Facebook Square(social network)' ),
				array( 'fa fa-linkedin-square' => 'LinkedIn Square' ),
				array( 'fa fa-github-square' => 'GitHub Square(octocat)' ),
				array( 'fa fa-twitter' => 'Twitter(tweet, social network)' ),
				array( 'fa fa-facebook' => 'Facebook(social network)(facebook-f)' ),
				array( 'fa fa-github' => 'GitHub(octocat)' ),
				array( 'fa fa-pinterest' => 'Pinterest' ),
				array( 'fa fa-pinterest-square' => 'Pinterest Square' ),
				array( 'fa fa-google-plus-square' => 'Google Plus Square(social network)' ),
				array( 'fa fa-google-plus' => 'Google Plus(social network)' ),
				array( 'fa fa-linkedin' => 'LinkedIn' ),
				array( 'fa fa-github-alt' => 'GitHub Alt(octocat)' ),
				array( 'fa fa-maxcdn' => 'MaxCDN' ),
				array( 'fa fa-html5' => 'HTML 5 Logo' ),
				array( 'fa fa-css3' => 'CSS 3 Logo(code)' ),
				array( 'fa fa-btc' => 'Bitcoin (BTC)(bitcoin)' ),
				array( 'fa fa-youtube-square' => 'YouTube Square(video, film)' ),
				array( 'fa fa-youtube' => 'YouTube(video, film)' ),
				array( 'fa fa-xing' => 'Xing' ),
				array( 'fa fa-xing-square' => 'Xing Square' ),
				array( 'fa fa-youtube-play' => 'YouTube Play(start, playing)' ),
				array( 'fa fa-dropbox' => 'Dropbox' ),
				array( 'fa fa-stack-overflow' => 'Stack Overflow' ),
				array( 'fa fa-instagram' => 'Instagram' ),
				array( 'fa fa-flickr' => 'Flickr' ),
				array( 'fa fa-adn' => 'App.net' ),
				array( 'fa fa-bitbucket' => 'Bitbucket(git)' ),
				array( 'fa fa-bitbucket-square' => 'Bitbucket Square(git)' ),
				array( 'fa fa-tumblr' => 'Tumblr' ),
				array( 'fa fa-tumblr-square' => 'Tumblr Square' ),
				array( 'fa fa-apple' => 'Apple(osx, food)' ),
				array( 'fa fa-windows' => 'Windows(microsoft)' ),
				array( 'fa fa-android' => 'Android(robot)' ),
				array( 'fa fa-linux' => 'Linux(tux)' ),
				array( 'fa fa-dribbble' => 'Dribbble' ),
				array( 'fa fa-skype' => 'Skype' ),
				array( 'fa fa-foursquare' => 'Foursquare' ),
				array( 'fa fa-trello' => 'Trello' ),
				array( 'fa fa-gratipay' => 'Gratipay (Gittip)(heart, like, favorite, love)(gittip)' ),
				array( 'fa fa-vk' => 'VK' ),
				array( 'fa fa-weibo' => 'Weibo' ),
				array( 'fa fa-renren' => 'Renren' ),
				array( 'fa fa-pagelines' => 'Pagelines(leaf, leaves, tree, plant, eco, nature)' ),
				array( 'fa fa-stack-exchange' => 'Stack Exchange' ),
				array( 'fa fa-vimeo-square' => 'Vimeo Square' ),
				array( 'fa fa-slack' => 'Slack Logo(hashtag, anchor, hash)' ),
				array( 'fa fa-wordpress' => 'WordPress Logo' ),
				array( 'fa fa-openid' => 'OpenID' ),
				array( 'fa fa-yahoo' => 'Yahoo Logo' ),
				array( 'fa fa-google' => 'Google Logo' ),
				array( 'fa fa-reddit' => 'reddit Logo' ),
				array( 'fa fa-reddit-square' => 'reddit Square' ),
				array( 'fa fa-stumbleupon-circle' => 'StumbleUpon Circle' ),
				array( 'fa fa-stumbleupon' => 'StumbleUpon Logo' ),
				array( 'fa fa-delicious' => 'Delicious Logo' ),
				array( 'fa fa-digg' => 'Digg Logo' ),
				array( 'fa fa-pied-piper-pp' => 'Pied Piper PP Logo (Old)' ),
				array( 'fa fa-pied-piper-alt' => 'Pied Piper Alternate Logo' ),
				array( 'fa fa-drupal' => 'Drupal Logo' ),
				array( 'fa fa-joomla' => 'Joomla Logo' ),
				array( 'fa fa-behance' => 'Behance' ),
				array( 'fa fa-behance-square' => 'Behance Square' ),
				array( 'fa fa-steam' => 'Steam' ),
				array( 'fa fa-steam-square' => 'Steam Square' ),
				array( 'fa fa-spotify' => 'Spotify' ),
				array( 'fa fa-deviantart' => 'deviantART' ),
				array( 'fa fa-soundcloud' => 'SoundCloud' ),
				array( 'fa fa-vine' => 'Vine' ),
				array( 'fa fa-codepen' => 'Codepen' ),
				array( 'fa fa-jsfiddle' => 'jsFiddle' ),
				array( 'fa fa-rebel' => 'Rebel Alliance(ra, resistance)' ),
				array( 'fa fa-empire' => 'Galactic Empire(ge)' ),
				array( 'fa fa-git-square' => 'Git Square' ),
				array( 'fa fa-git' => 'Git' ),
				array( 'fa fa-hacker-news' => 'Hacker News(y-combinator-square, yc-square)' ),
				array( 'fa fa-tencent-weibo' => 'Tencent Weibo' ),
				array( 'fa fa-qq' => 'QQ' ),
				array( 'fa fa-weixin' => 'Weixin (WeChat)(wechat)' ),
				array( 'fa fa-share-alt' => 'Share Alt' ),
				array( 'fa fa-share-alt-square' => 'Share Alt Square' ),
				array( 'fa fa-slideshare' => 'Slideshare' ),
				array( 'fa fa-twitch' => 'Twitch' ),
				array( 'fa fa-yelp' => 'Yelp' ),
				array( 'fa fa-paypal' => 'Paypal' ),
				array( 'fa fa-google-wallet' => 'Google Wallet' ),
				array( 'fa fa-cc-visa' => 'Visa Credit Card' ),
				array( 'fa fa-cc-mastercard' => 'MasterCard Credit Card' ),
				array( 'fa fa-cc-discover' => 'Discover Credit Card' ),
				array( 'fa fa-cc-amex' => 'American Express Credit Card(amex)' ),
				array( 'fa fa-cc-paypal' => 'Paypal Credit Card' ),
				array( 'fa fa-cc-stripe' => 'Stripe Credit Card' ),
				array( 'fa fa-lastfm' => 'last.fm' ),
				array( 'fa fa-lastfm-square' => 'last.fm Square' ),
				array( 'fa fa-ioxhost' => 'ioxhost' ),
				array( 'fa fa-angellist' => 'AngelList' ),
				array( 'fa fa-meanpath' => 'meanpath' ),
				array( 'fa fa-buysellads' => 'BuySellAds' ),
				array( 'fa fa-connectdevelop' => 'Connect Develop' ),
				array( 'fa fa-dashcube' => 'DashCube' ),
				array( 'fa fa-forumbee' => 'Forumbee' ),
				array( 'fa fa-leanpub' => 'Leanpub' ),
				array( 'fa fa-sellsy' => 'Sellsy' ),
				array( 'fa fa-shirtsinbulk' => 'Shirts in Bulk' ),
				array( 'fa fa-simplybuilt' => 'SimplyBuilt' ),
				array( 'fa fa-skyatlas' => 'skyatlas' ),
				array( 'fa fa-facebook-official' => 'Facebook Official' ),
				array( 'fa fa-pinterest-p' => 'Pinterest P' ),
				array( 'fa fa-whatsapp' => 'What\'s App' ),
				array( 'fa fa-viacoin' => 'Viacoin' ),
				array( 'fa fa-medium' => 'Medium' ),
				array( 'fa fa-y-combinator' => 'Y Combinator(yc)' ),
				array( 'fa fa-optin-monster' => 'Optin Monster' ),
				array( 'fa fa-opencart' => 'OpenCart' ),
				array( 'fa fa-expeditedssl' => 'ExpeditedSSL' ),
				array( 'fa fa-cc-jcb' => 'JCB Credit Card' ),
				array( 'fa fa-cc-diners-club' => 'Diner\'s Club Credit Card' ),
				array( 'fa fa-gg' => 'GG Currency' ),
				array( 'fa fa-gg-circle' => 'GG Currency Circle' ),
				array( 'fa fa-tripadvisor' => 'TripAdvisor' ),
				array( 'fa fa-odnoklassniki' => 'Odnoklassniki' ),
				array( 'fa fa-odnoklassniki-square' => 'Odnoklassniki Square' ),
				array( 'fa fa-get-pocket' => 'Get Pocket' ),
				array( 'fa fa-wikipedia-w' => 'Wikipedia W' ),
				array( 'fa fa-safari' => 'Safari(browser)' ),
				array( 'fa fa-chrome' => 'Chrome(browser)' ),
				array( 'fa fa-firefox' => 'Firefox(browser)' ),
				array( 'fa fa-opera' => 'Opera' ),
				array( 'fa fa-internet-explorer' => 'Internet-explorer(browser, ie)' ),
				array( 'fa fa-contao' => 'Contao' ),
				array( 'fa fa-500px' => '500px' ),
				array( 'fa fa-amazon' => 'Amazon' ),
				array( 'fa fa-houzz' => 'Houzz' ),
				array( 'fa fa-vimeo' => 'Vimeo' ),
				array( 'fa fa-black-tie' => 'Font Awesome Black Tie' ),
				array( 'fa fa-fonticons' => 'Fonticons' ),
				array( 'fa fa-reddit-alien' => 'reddit Alien' ),
				array( 'fa fa-edge' => 'Edge Browser(browser, ie)' ),
				array( 'fa fa-codiepie' => 'Codie Pie' ),
				array( 'fa fa-modx' => 'MODX' ),
				array( 'fa fa-fort-awesome' => 'Fort Awesome' ),
				array( 'fa fa-usb' => 'USB' ),
				array( 'fa fa-product-hunt' => 'Product Hunt' ),
				array( 'fa fa-mixcloud' => 'Mixcloud' ),
				array( 'fa fa-scribd' => 'Scribd' ),
				array( 'fa fa-bluetooth' => 'Bluetooth' ),
				array( 'fa fa-bluetooth-b' => 'Bluetooth' ),
				array( 'fa fa-gitlab' => 'GitLab' ),
				array( 'fa fa-wpbeginner' => 'WPBeginner' ),
				array( 'fa fa-wpforms' => 'WPForms' ),
				array( 'fa fa-envira' => 'Envira Gallery(leaf)' ),
				array( 'fa fa-glide' => 'Glide' ),
				array( 'fa fa-glide-g' => 'Glide G' ),
				array( 'fa fa-viadeo' => 'Viadeo' ),
				array( 'fa fa-viadeo-square' => 'Viadeo Square' ),
				array( 'fa fa-snapchat' => 'Snapchat' ),
				array( 'fa fa-snapchat-ghost' => 'Snapchat Ghost' ),
				array( 'fa fa-snapchat-square' => 'Snapchat Square' ),
				array( 'fa fa-pied-piper' => 'Pied Piper Logo' ),
				array( 'fa fa-first-order' => 'First Order' ),
				array( 'fa fa-yoast' => 'Yoast' ),
				array( 'fa fa-themeisle' => 'ThemeIsle' ),
				array( 'fa fa-google-plus-official' => 'Google Plus Official(google-plus-circle)' ),
				array( 'fa fa-font-awesome' => 'Font Awesome(fa)' ),
				array( 'fa fa-linode' => 'Linode' ),
				array( 'fa fa-quora' => 'Quora' ),
				array( 'fa fa-free-code-camp' => 'Free Code Camp' ),
				array( 'fa fa-telegram' => 'Telegram' ),
				array( 'fa fa-bandcamp' => 'Bandcamp' ),
				array( 'fa fa-grav' => 'Grav' ),
				array( 'fa fa-etsy' => 'Etsy' ),
				array( 'fa fa-imdb' => 'IMDB' ),
				array( 'fa fa-ravelry' => 'Ravelry' ),
				array( 'fa fa-eercast' => 'Eercast' ),
				array( 'fa fa-superpowers' => 'Superpowers' ),
				array( 'fa fa-wpexplorer' => 'WPExplorer' ),
				array( 'fa fa-meetup' => 'Meetup' ),
			),
			'Hand Icons' => array(
				array( 'fa fa-thumbs-o-up' => 'Thumbs Up Outlined(like, approve, favorite, agree, hand)' ),
				array( 'fa fa-thumbs-o-down' => 'Thumbs Down Outlined(dislike, disapprove, disagree, hand)' ),
				array( 'fa fa-hand-o-right' => 'Hand Outlined Right(point, right, next, forward, finger)' ),
				array( 'fa fa-hand-o-left' => 'Hand Outlined Left(point, left, previous, back, finger)' ),
				array( 'fa fa-hand-o-up' => 'Hand Outlined Up(point, finger)' ),
				array( 'fa fa-hand-o-down' => 'Hand Outlined Down(point, finger)' ),
				array( 'fa fa-thumbs-up' => 'thumbs-up(like, favorite, approve, agree, hand)' ),
				array( 'fa fa-thumbs-down' => 'thumbs-down(dislike, disapprove, disagree, hand)' ),
				array( 'fa fa-hand-rock-o' => 'Rock (Hand)(hand-grab-o)' ),
				array( 'fa fa-hand-paper-o' => 'Paper (Hand)(stop)(hand-stop-o)' ),
				array( 'fa fa-hand-scissors-o' => 'Scissors (Hand)' ),
				array( 'fa fa-hand-lizard-o' => 'Lizard (Hand)' ),
				array( 'fa fa-hand-spock-o' => 'Spock (Hand)' ),
				array( 'fa fa-hand-pointer-o' => 'Hand Pointer' ),
				array( 'fa fa-hand-peace-o' => 'Hand Peace' ),
			),
			'Payment Icons' => array(
				array( 'fa fa-credit-card' => 'credit-card(money, buy, debit, checkout, purchase, payment)' ),
				array( 'fa fa-paypal' => 'Paypal' ),
				array( 'fa fa-google-wallet' => 'Google Wallet' ),
				array( 'fa fa-cc-visa' => 'Visa Credit Card' ),
				array( 'fa fa-cc-mastercard' => 'MasterCard Credit Card' ),
				array( 'fa fa-cc-discover' => 'Discover Credit Card' ),
				array( 'fa fa-cc-amex' => 'American Express Credit Card(amex)' ),
				array( 'fa fa-cc-paypal' => 'Paypal Credit Card' ),
				array( 'fa fa-cc-stripe' => 'Stripe Credit Card' ),
				array( 'fa fa-cc-jcb' => 'JCB Credit Card' ),
				array( 'fa fa-cc-diners-club' => 'Diner\'s Club Credit Card' ),
				array( 'fa fa-credit-card-alt' => 'Credit Card(money, buy, debit, checkout, purchase, payment, credit card)' ),
			),
			'Currency Icons' => array(
				array( 'fa fa-money' => 'Money(cash, money, buy, checkout, purchase, payment)' ),
				array( 'fa fa-eur' => 'Euro (EUR)(euro)' ),
				array( 'fa fa-gbp' => 'GBP' ),
				array( 'fa fa-usd' => 'US Dollar(dollar)' ),
				array( 'fa fa-inr' => 'Indian Rupee (INR)(rupee)' ),
				array( 'fa fa-jpy' => 'Japanese Yen (JPY)(cny, rmb, yen)' ),
				array( 'fa fa-rub' => 'Russian Ruble (RUB)(ruble, rouble)' ),
				array( 'fa fa-krw' => 'Korean Won (KRW)(won)' ),
				array( 'fa fa-btc' => 'Bitcoin (BTC)(bitcoin)' ),
				array( 'fa fa-try' => 'Turkish Lira (TRY)(turkish-lira)' ),
				array( 'fa fa-ils' => 'Shekel (ILS)(shekel, sheqel)' ),
				array( 'fa fa-gg' => 'GG Currency' ),
				array( 'fa fa-gg-circle' => 'GG Currency Circle' ),
			),
			'Accessibility Icons' => array(
				array( 'fa fa-wheelchair' => 'Wheelchair(handicap, person)' ),
				array( 'fa fa-tty' => 'TTY' ),
				array( 'fa fa-cc' => 'Closed Captions' ),
				array( 'fa fa-universal-access' => 'Universal Access' ),
				array( 'fa fa-wheelchair-alt' => 'Wheelchair Alt(handicap, person)' ),
				array( 'fa fa-question-circle-o' => 'Question Circle Outlined' ),
				array( 'fa fa-blind' => 'Blind' ),
				array( 'fa fa-audio-description' => 'Audio Description' ),
				array( 'fa fa-volume-control-phone' => 'Volume Control Phone(telephone)' ),
				array( 'fa fa-braille' => 'Braille' ),
				array( 'fa fa-assistive-listening-systems' => 'Assistive Listening Systems' ),
				array( 'fa fa-american-sign-language-interpreting' => 'American Sign Language Interpreting(asl-interpreting)' ),
				array( 'fa fa-deaf' => 'Deaf(deafness, hard-of-hearing)' ),
				array( 'fa fa-sign-language' => 'Sign Language(signing)' ),
				array( 'fa fa-low-vision' => 'Low Vision' ),
			),
			'Gender Icons' => array(
				array( 'fa fa-venus' => 'Venus(female)' ),
				array( 'fa fa-mars' => 'Mars(male)' ),
				array( 'fa fa-mercury' => 'Mercury(transgender)' ),
				array( 'fa fa-transgender' => 'Transgender(intersex)' ),
				array( 'fa fa-transgender-alt' => 'Transgender Alt' ),
				array( 'fa fa-venus-double' => 'Venus Double' ),
				array( 'fa fa-mars-double' => 'Mars Double' ),
				array( 'fa fa-venus-mars' => 'Venus Mars' ),
				array( 'fa fa-mars-stroke' => 'Mars Stroke' ),
				array( 'fa fa-mars-stroke-v' => 'Mars Stroke Vertical' ),
				array( 'fa fa-mars-stroke-h' => 'Mars Stroke Horizontal' ),
				array( 'fa fa-neuter' => 'Neuter' ),
				array( 'fa fa-genderless' => 'Genderless' ),
			),
		);
		
		return $fontawesome_icons;
	}
}


if(!function_exists('ciyashop_breadcrumbs')) {
    function ciyashop_breadcrumbs($class = '') {
		global $ciyashop_options;


        // Do not display on the homepage
        if (is_front_page()) return;

        // Get the query & post information
        global $post, $wp_query;

        $breadcrums_id = 'ciyashop_breadcrumbs';
        $breadcrums_class = 'ciyashop_breadcrumbs page-breadcrumb breadcrumbs';
        $home_title = __('Home', 'ciyashop');
        $parents = '';

		if($class != '') {
			$breadcrums_class .= ' '.$class;
		}

        // If you have any custom post types with custom taxonomies, put the taxonomy name below (e.g. product_cat)
        $custom_taxonomy = array();

        $output = '';
        $output .= '<ul id="' . $breadcrums_id . '" class="' . $breadcrums_class . '">';

        // Home page
        $output .= '<li class="home"><span class="item-element"><a class="bread-link bread-home" href="' . get_home_url() . '" title="' . $home_title . '">' . $home_title . '</a></span></li>';

        if (is_home()) {
            $page_id = get_queried_object_id();
            $output .= '<li class="current-item item-home-page"><span class="item-element">';
            $output .= get_the_title($page_id);
            $output .= '</span></li>';
        }
        if (is_archive() && !is_tax() && !is_category() && !is_tag() && !is_author()) {
            $output .= '<li class="current-item item-archive">';
            if (is_day()) :
                $output .= __('Daily Archives:', 'ciyashop'). ' <span class="item-element">' . get_the_date() . '</span>';
            elseif (is_month()) :
                $output .= __('Monthly Archives:', 'ciyashop'). ' <span class="item-element">' . get_the_date(_x('F Y', 'monthly archives date format', 'ciyashop')) . '</span>';
            elseif (is_year()) :
                $output .= __('Yearly Archives:', 'ciyashop'). ' <span class="item-element">' . get_the_date(_x('Y', 'yearly archives date format', 'ciyashop')) . '</span>';
            else :
                $output .= post_type_archive_title($prefix = '', false);
            endif;
            $output .= '</li>';
        } else if (is_archive() && is_tax() && !is_category() && !is_tag()) {
            // If post is a custom post type
            $post_type = get_post_type();

            // If it is a custom post type display name and link
            if ($post_type != 'post') {
                $post_type_object = get_post_type_object($post_type);
                $post_type_archive = get_post_type_archive_link($post_type);
                $output .= '<li class="item-cat item-custom-post-type-' . $post_type . '"><span class="item-element"><a class="bread-cat bread-custom-post-type-' . $post_type . '" href="' . $post_type_archive . '" title="' . $post_type_object->labels->name . '">' . $post_type_object->labels->name . '</a></span></li>';
            }

            $custom_tax_name = get_queried_object()->name;
            $output .= '<li class="current-item item-archive"><span class="item-element">' . $custom_tax_name . '</span></li>';
        } else if (is_single()) {
            // If post is a custom post type
            $post_type = get_post_type();

            // If it is a custom post type display name and link
            if ($post_type != 'post') {
                $post_type_object = get_post_type_object($post_type);
                $post_type_archive = get_post_type_archive_link($post_type);
                $output .= '<li class="item-cat item-custom-post-type-' . $post_type . '"><span class="item-element"><a class="bread-cat bread-custom-post-type-' . $post_type . '" href="' . $post_type_archive . '" title="' . $post_type_object->labels->name . '">' . $post_type_object->labels->name . '</a></span></li>';
            }

            // Get post category info
            $category = get_the_category();
			if( $post_type == 'product' ){
				$category = get_the_terms(get_the_ID(), 'product_cat');
			}
            if (!empty($category)) {
                // Get last category post is in
                $values_of_category = array_values($category);
                $last_category = end($values_of_category);
                // Get parent any categories and create array
                $get_cat_parents = rtrim(get_category_parents($last_category->term_id, true, ','), ',');
                $cat_parents     = explode(',', $get_cat_parents);
                $cat_display = '';
				if( $post_type == 'product' ){
					$cats_id = array_column(get_the_terms(get_the_ID(), 'product_cat') , 'term_id' );
					// Show only onw category
					$cats_id = reset($cats_id);
					if( ! empty($cats_id) ){
						$get_cat_parents = ( ! empty( $cats_id )) ? get_ancestors($cats_id, 'product_cat') : '';
						$cat_link = get_term_link($cats_id);
						$last_cat= get_term_by( 'id', $cats_id, 'product_cat' );
						if( ! empty( $get_cat_parents ) ){
							// Show only one category
							$get_cat_parents= get_term_by( 'id', $get_cat_parents[0], 'product_cat' );
							$parents_cat_link = get_term_link($get_cat_parents->term_id, 'product_cat');
							$cat_display .= '<li class="item-cat"><span class="item-element"><a href="' . $parents_cat_link . '">' . $get_cat_parents->name . '</a></span></li>';	
						}
						$cat_display .= '<li class="item-cat"><span class="item-element"><a href="' . $cat_link . '">' . $last_cat->name . '</a></span></li>';
					}
				}
				
                // Loop through parent categories and store in variable $cat_display
				if( !empty($cat_parents) && is_array($cat_parents) ){
					foreach ($cat_parents as $parents) {
						$cat_display .= ( empty($parents) )?'':'<li class="item-cat"><span class="item-element">' . $parents . '</span></li>';
					}
				}
            }

            // If it's a custom post type within a custom taxonomy
            foreach($custom_taxonomy as $taxonomy) {
                $taxonomy_exists = taxonomy_exists($taxonomy);
                if (empty($last_category) && !empty($taxonomy) && $taxonomy_exists) {
                    $taxonomy_terms = get_the_terms($post->ID, $taxonomy);
                    if (isset($taxonomy_terms[0])) {
                        $cat_id       = $taxonomy_terms[0]->term_id;
                        $cat_nicename = $taxonomy_terms[0]->slug;
                        $cat_link     = get_term_link($taxonomy_terms[0]->term_id, $taxonomy);
                        $cat_name     = $taxonomy_terms[0]->name;
                    }
                }
            }

            // Check if the post is in a category
            if (!empty($last_category)) {
                $output .= $cat_display;
                $output .= '<li class="current-item item-' . $post->ID . '"><span class="item-element">' . get_the_title() . '</span></li>';
            } else if (!empty($cat_id)) {
                // Else if post is in a custom taxonomy
                $output .= '<li class="item-cat item-cat-' . $cat_id . ' item-cat-' . $cat_nicename . '"><span class="item-element"><a class="bread-cat bread-cat-' . $cat_id . ' bread-cat-' . $cat_nicename . '" href="' . $cat_link . '" title="' . $cat_name . '">' . $cat_name . '</a></span></li>';
                $output .= '<li class="current-item item-' . $post->ID . '"><span class="item-element">' . get_the_title() . '</span></li>';
            } else {
                $output .= '<li class="current-item item-' . $post->ID . '"><span class="item-element">' . get_the_title() . '</span></li>';
            }
        } elseif (is_category()) {
            // Category page
            $bread_cat_id   = get_cat_id(single_cat_title("", false));
            $bread_cat      = get_category_parents($bread_cat_id, 'true', ';');
            $bread_cat      = explode(';', $bread_cat);
            $bread_cat_size = sizeof($bread_cat);
            $i              = 1;

            foreach ($bread_cat as $bread) {
                if ($bread != '') {
                    if ($bread_cat_size == $i + 1) {
                        $output .= '<li class="current-item item-cat"><span class="item-element">' . $bread . '</span></li>';
                    } else {
                        $output .= '<li class="current-item item-cat"><span class="item-element">' . $bread . '</span></li>';
                    }
                    $i++;
                }
            }
        } elseif (is_page()) {
            // Standard page
            if ($post->post_parent) {
                // If child page, get parents
                $anc = get_post_ancestors($post->ID);

                // Get parents in the right order
                $anc = array_reverse($anc);

                // Parent page loop
                foreach ($anc as $ancestor) {
                    $parents .= '<li class="item-parent item-parent-' . $ancestor . '"><span class="item-element"><a class="bread-parent bread-parent-' . $ancestor . '" href="' . get_permalink($ancestor) . '" title="' . get_the_title($ancestor) . '">' . get_the_title($ancestor) . '</a></span></li>';
                }

                // Display parent pages
                $output .= $parents;

                // Current page
                $output .= '<li class="current-item item-' . $post->ID . '"><span class="item-element">' . get_the_title() . '</span></li>';
            } else {
                // Just display current page if not parents
                $output .= '<li class="current-item item-' . $post->ID . '"><span class="item-element">' . get_the_title() . '</span></li>';
            }
        } elseif(is_tag()) {
            // Tag page

            // Get tag information
            $term_id  = get_query_var('tag_id');
            $taxonomy = 'post_tag';
            $args     = 'include=' . $term_id;
            $terms    = get_terms($taxonomy, $args);
            if (array_filter($terms)) {
                $get_term_id   = $terms[0]->term_id;
                $get_term_slug = $terms[0]->slug;
                $get_term_name = $terms[0]->name;

                // Display the tag name
                $output .= '<li class="current-item item-tag-' . $get_term_id . ' item-tag-' . $get_term_slug . '"><span class="item-element">' . $get_term_name . '</span></li>';
            }

        } elseif (is_day()) {
            // Day archive

            // Year link
            $output .= '<li class="item-year item-year-' . get_the_time('Y') . '"><span class="item-element"><a class="bread-year bread-year-' . get_the_time('Y') . '" href="' . get_year_link(get_the_time('Y')) . '" title="' . get_the_time('Y') . '">' . get_the_time('Y') . '&nbsp;' . __('Archives', 'ciyashop') . '</a></span></li>';

            // Month link
            $output .= '<li class="item-month item-month-' . get_the_time('m') . '"><span class="item-element"><a class="bread-month bread-month-' . get_the_time('m') . '" href="' . get_month_link(get_the_time('Y'), get_the_time('m')) . '" title="' . get_the_time('M') . '">' . get_the_time('M') . '&nbsp;' . __('.Archives', 'ciyashop') . '</a></span></li>';

            // Day display
            $output .= '<li class="current-item item-' . get_the_time('j') . '"><span class="item-element">' . get_the_time('jS') . ' ' . get_the_time('M') . '&nbsp;' . __('Archives', 'ciyashop') . '</span></li>';
        } elseif (is_month()) {
            // Month Archive

            // Year link
            $output .= '<li class="item-year item-year-' . get_the_time('Y') . '"><span class="item-element"><a class="bread-year bread-year-' . get_the_time('Y') . '" href="' . get_year_link(get_the_time('Y')) . '" title="' . get_the_time('Y') . '">' . get_the_time('Y') . '&nbsp;' . __('Archives', 'ciyashop') . '</a></span></li>';

            // Month display
            $output .= '<li class="item-month item-month-' . get_the_time('m') . '"><span class="item-element">' . get_the_time('M') . '&nbsp;' . __('Archives', 'ciyashop') . '</span></li>';
        } elseif (is_year()) {
            // Display year archive
            $output .= '<li class="current-item item-current-' . get_the_time('Y') . '"><span class="item-element">' . get_the_time('Y') . '&nbsp;' . __('Archives', 'ciyashop') . '</span></li>';
        } elseif (is_author()) {
            // Auhor archive
            // Get the author information
            global $author;
            $userdata = get_userdata($author);
            // Display author name
            $output .= '<li class="current-item item-current-' . $userdata->user_nicename . '"><span class="item-element">' . ' ' . $userdata->display_name . '</span></li>';
        } elseif (get_query_var('paged') && !is_home()) {
            // Paginated archives
            $output .= '<li class="current-item item-current-' . get_query_var('paged') . '"><span class="item-element">' . __('Page', 'ciyashop') . ' ' . get_query_var('paged') . '</span></li>';
        } elseif (is_search()) {
            // Search results page
            $output .= '<li class="current-item item-current-' . get_search_query() . '"><span class="item-element">' . __('Search results for', 'ciyashop') . ': ' . get_search_query() . '</span></li>';
        }

        $output .= '</ul>';

        return $output;
    }
}

// Create Google Fonts url
if( ! function_exists( 'ciyashop_create_google_fonts_url' ) ) {
	function ciyashop_create_google_fonts_url( $fonts ){

		$link    = "";
        $subsets = array();
		$protocol = ( ! empty ( $_SERVER['HTTPS'] ) && $_SERVER['HTTPS'] !== 'off' || $_SERVER['SERVER_PORT'] == 443 ) ? "https:" : "http:";

		foreach ( $fonts as  $font ) {
			if( !empty($font['font-family']) ){

				if ( ! empty( $link ) ) {
					$link .= "%7C"; // Append a new font to the string
				}

				$link .= $font['font-family'];

				if ( ! empty( $font['font-style'] ) || ! empty( $font['font-weight'] ) || ! empty( $font['all-styles'] ) ) {
					$link .= ':';

					if ( ! empty( $font['all-styles'] ) ) {
						$link .= implode( ',', $font['all-styles'] );
					} else if ( ! empty( $font['font-weight'] ) || ! empty( $font['font-style'] ) ) {

						if( ! empty( $font['font-weight'] ) ){
							$link .= $font['font-weight'];
						}

						if( ! empty( $font['font-weight'] ) ){
							$link .= $font['font-style'];
						}
					}
				}

				if ( ! empty( $font['subsets'] ) ) {
					if(is_array($font['subsets'])){
						foreach ( $font['subsets'] as $subset ) {
							if ( ! in_array( $subset, $subsets ) ) {
								array_push( $subsets, $subset );
							}
						}
					}else{
						array_push( $subsets, $font['subsets'] );
					}
				}

			}
		}

		if ( ! empty( $subsets ) ) {
			$link .= "&subset=" . implode( ',', $subsets );
		}

		if(empty($link)) return;

		return $protocol.'//fonts.googleapis.com/css?family=' . str_replace( '|', '%7C', $link );
	}
}

if( ! function_exists( 'ciyashop_get_tooltip_position' ) ) {
	function ciyashop_get_tooltip_position(){
		global $ciyashop_options;

		$product_hover_style = ciyashop_product_hover_style();
		$positions = array();

		switch( $product_hover_style ) {
			case 'default':
				$cart_position = 0;
				$wishlist_position = 'top';
				$compare_position = 'top';
				$quick_view_position = 'right';
			break;
			case 'icon-top-left':
				$cart_position = 'right';
				$wishlist_position = 'left';
				$compare_position = 'right';
				$quick_view_position = 'right';
			break;
			case 'icons-top-right':
				$cart_position = 'left';
				$wishlist_position = 'left';
				$compare_position = 'left';
				$quick_view_position = 'left';
			break;
			case 'image-icon-left':
				$cart_position = 'right';
				$wishlist_position = 'right';
				$compare_position = 'right';
				$quick_view_position = 0;
			break;
			case 'image-icon-bottom':
				$cart_position = 'top';
				$wishlist_position = 'top';
				$compare_position = 'top';
				$quick_view_position = 0;
			break;
			case 'image-center':
				$cart_position = 'top';
				$wishlist_position = 'top';
				$compare_position = 'top';
				$quick_view_position = 0;
			break;
			case 'image-left':
				$cart_position = 0;
				$wishlist_position = 'right';
				$compare_position = 'right';
				$quick_view_position = 'right';
			break;
			case 'button-standard':
				$cart_position = 0;
				$wishlist_position = 'top';
				$compare_position = 'top';
				$quick_view_position = 'top';
			break;
			case 'icons-left':
				$cart_position = 0;
				$wishlist_position = 'right';
				$compare_position = 'right';
				$quick_view_position = 'right';
			break;
			case 'icons-rounded':
				$cart_position = 0;
				$wishlist_position = 'right';
				$compare_position = 'right';
				$quick_view_position = 'right';
			break;
			case 'icons-bottom-right':
				$cart_position = 'left';
				$wishlist_position = 'left';
				$compare_position = 'left';
				$quick_view_position = 'left';
			break;
			case 'image-bottom':
				$cart_position = 'top';
				$wishlist_position = 'top';
				$compare_position = 'top';
				$quick_view_position = 'top';
			break;
			case 'image-bottom-2':
				$cart_position = 'top';
				$wishlist_position = 'top';
				$compare_position = 'top';
				$quick_view_position = 'top';
			break;
			case 'image-bottom-bar':
				$cart_position = 0;
				$wishlist_position = 'top';
				$compare_position = 'top';
				$quick_view_position = 0;
			break;
			case 'info-bottom':
				$cart_position = 0;
				$wishlist_position = 'top';
				$compare_position = 'top';
				$quick_view_position = 0;
			break;
			case 'info-bottom-bar':
				$cart_position = 0;
				$wishlist_position = 'top';
				$compare_position = 'top';
				$quick_view_position = 0;
			break;
			case 'hover-summary':
				$cart_position = 0;
				$wishlist_position = 'right';
				$compare_position = 'top';
				$quick_view_position = 'top';
			break;
			case 'minimal-hover-cart':
				$cart_position = 0;
				$wishlist_position = 'top';
				$compare_position = 'top';
				$quick_view_position = 'top';
			break;
			case 'minimal':
				$cart_position = 0;
				$wishlist_position = 'top';
				$compare_position = 'top';
				$quick_view_position = 0;
			break;
			case 'info-transparent-center':
				$cart_position = 0;
				$wishlist_position = 'top';
				$compare_position = 'top';
				$quick_view_position = 'top';
			break;
			case 'icons-transparent-center':
				$cart_position = 0;
				$wishlist_position = 'top';
				$compare_position = 'top';
				$quick_view_position = 'top';
			break;
			case 'standard-info-transparent':
				$cart_position = 'left';
				$wishlist_position = 'left';
				$compare_position = 'left';
				$quick_view_position = 'left';
			break;
			case 'standard-quick-shop':
				$cart_position = 0;
				$wishlist_position = 'left';
				$compare_position = 'left';
				$quick_view_position = 'left';
			break;
			default:
				$cart_position = 'top';
				$wishlist_position = 'top';
				$compare_position = 'top';
				$quick_view_position = 'top';
		}

		$positions = array(
			'cart_icon' => $cart_position,
			'wishlist_icon' => $wishlist_position,
			'compare_icon' => $compare_position,
			'quick_view_icon' => $quick_view_position,
		);

		return $positions;
	}
}

add_action( 'ciyashop_before_page_wrapper', 'ciyashop_before_page_wrapper_check' );

if( ! function_exists( 'ciyashop_before_page_wrapper_check' ) ) {
	function ciyashop_before_page_wrapper_check(){
		$ciyashop_theme_options = get_option('ciyashop_options');
		global $cs_product_list_styles, $ciyashop_options;

		if( isset($ciyashop_options['product_hover_style']) && $ciyashop_options['product_hover_style'] ){
			switch($ciyashop_options['product_hover_style']){
				case $cs_product_list_styles['default']:
				case $cs_product_list_styles['image-icon-left']:
				case $cs_product_list_styles['image-icon-bottom']:
				case $cs_product_list_styles['icons-center']:
				case $cs_product_list_styles['minimal']:
				case $cs_product_list_styles['icons-bottom-bar'];
				case $cs_product_list_styles['info-bottom'];
				case $cs_product_list_styles['info-bottom-bar'];
					add_action( 'woocommerce_before_shop_loop_item_title', 'ciyashop_product_actions_add_quick_view_link', 20 );
				break;
				default:
					add_action( 'ciyashop_product_actions', 'ciyashop_product_actions_add_quick_view_link', 20 );
			}
		}
	}
}

if( ! function_exists( 'ciyashop_product_actions_add_quick_view_link' ) ) {
	function ciyashop_product_actions_add_quick_view_link(){
		global $post, $ciyashop_options;

		if(!$ciyashop_options['quick_view']){
			return;
		}

		$position = ciyashop_get_tooltip_position();
		$quick_view_icon_position = isset($position['quick_view_icon']) ? $position['quick_view_icon'] : '';
		?>
		<div class="product-action product-action-quick-view">
			<?php
			if( $quick_view_icon_position ){
				?>
				<a href="<?php echo esc_url( get_the_permalink($post->ID) ); ?>" class="open-quick-view" data-id="<?php echo esc_attr( $post->ID ); ?>" data-toggle='tooltip' data-original-title="<?php esc_attr_e( 'Quick view', 'ciyashop' );?>" data-placement='<?php echo esc_attr($quick_view_icon_position )?>'>
					<?php esc_html_e('Quick View', 'ciyashop' ); ?>
				</a>
				<?php
			} else {
				?>
				<a href="<?php echo esc_url( get_the_permalink($post->ID) ); ?>" class="open-quick-view" data-id="<?php echo esc_attr( $post->ID ); ?>">
					<?php esc_html_e('Quick View', 'ciyashop' ); ?>
				</a>
				<?php
			}
			?>
		</div>
		<?php
	}
}

if( ! function_exists( 'ciyashop_get_selected_menu_id' ) ) {
	function ciyashop_get_selected_menu_id() {

		$nav_menus = wp_get_nav_menus( array('orderby' => 'name') );

		$menu_count = count( $nav_menus );

		$nav_menu_selected_id = isset( $_REQUEST['menu'] ) ? (int) $_REQUEST['menu'] : 0;

		$add_new_screen = ( isset( $_GET['menu'] ) && 0 == $_GET['menu'] ) ? true : false;

		// If we have one theme location, and zero menus, we take them right into editing their first menu
		$page_count = wp_count_posts( 'page' );
		$one_theme_location_no_menus = ( 1 == count( get_registered_nav_menus() ) && ! $add_new_screen && empty( $nav_menus ) && ! empty( $page_count->publish ) ) ? true : false;

		// Get recently edited nav menu
		$recently_edited = absint( get_user_option( 'nav_menu_recently_edited' ) );
		if ( empty( $recently_edited ) && is_nav_menu( $nav_menu_selected_id ) )
			$recently_edited = $nav_menu_selected_id;

		// Use $recently_edited if none are selected
		if ( empty( $nav_menu_selected_id ) && ! isset( $_GET['menu'] ) && is_nav_menu( $recently_edited ) )
			$nav_menu_selected_id = $recently_edited;

		// On deletion of menu, if another menu exists, show it
		if ( ! $add_new_screen && 0 < $menu_count && isset( $_GET['action'] ) && 'delete' == $_GET['action'] )
			$nav_menu_selected_id = $nav_menus[0]->term_id;

		// Set $nav_menu_selected_id to 0 if no menus
		if ( $one_theme_location_no_menus ) {
			$nav_menu_selected_id = 0;
		} elseif ( empty( $nav_menu_selected_id ) && ! empty( $nav_menus ) && ! $add_new_screen ) {
			// if we have no selection yet, and we have menus, set to the first one in the list
			$nav_menu_selected_id = $nav_menus[0]->term_id;
		}

		return $nav_menu_selected_id;

	}
}
